@@ -26,7 +26,7 @@ BinUnitsModel::BinUnitsModel(Catalog* catalog, QObject* parent)
     : QAbstractListModel(parent)
     , m_catalog(catalog)
 {
-    connect(catalog, QOverload<>::of(&Catalog::signalFileLoaded), this, &BinUnitsModel::fileLoaded);
+    connect(catalog, qOverload<>(&Catalog::signalFileLoaded), this, &BinUnitsModel::fileLoaded);
     connect(catalog, &Catalog::signalEntryModified, this, &BinUnitsModel::entryModified);
     connect(KDirWatch::self(), &KDirWatch::dirty, this, &BinUnitsModel::updateFile);
 }
@@ -110,7 +110,7 @@ QVariant BinUnitsModel::data(const QModelIndex& index, int role) const
     switch (index.column()) {
     case SourceFilePath:    return m_catalog->source(pos);
     case TargetFilePath:    return m_catalog->target(pos);
-    case Approved:          return noyes[m_catalog->isApproved(pos)];
+    case Approved:          return QString::fromLocal8Bit(noyes[m_catalog->isApproved(pos)]);
     }
     return QVariant();
 }
@@ -146,7 +146,7 @@ BinUnitsView::BinUnitsView(Catalog* catalog, QWidget* parent)
     m_view->viewport()->setBackgroundRole(QPalette::Window);
     connect(m_view, &MyTreeView::doubleClicked, this, &BinUnitsView::mouseDoubleClicked);
 
-    connect(catalog, QOverload<>::of(&Catalog::signalFileLoaded), this, &BinUnitsView::fileLoaded);
+    connect(catalog, qOverload<>(&Catalog::signalFileLoaded), this, &BinUnitsView::fileLoaded);
 }
 
 void BinUnitsView::fileLoaded()
@@ -197,3 +197,5 @@ void BinUnitsView::mouseDoubleClicked(const QModelIndex& item)
     if (item.column() < BinUnitsModel::Approved)
         new KRun(QUrl::fromLocalFile(Project::instance()->absolutePath(item.data().toString())), this);
 }
+
+#include "moc_binunitsview.cpp"
