@@ -18,14 +18,12 @@
 
 #include "catalogstorage.h"
 #include "gettextstorage.h"
-#include "gettextimport.h"
-#include "gettextexport.h"
 #include "xliffstorage.h"
 #include "tsstorage.h"
 
 #include "mergecatalog.h"
 
-#include "version.h"
+#include "lokalize_debug.h"
 #include "prefs_lokalize.h"
 #include "jobs.h"
 #include "dbfilesmodel.h"
@@ -39,21 +37,23 @@
 
 #include <klocalizedstring.h>
 
-#ifdef Q_OS_WIN
-#define U QLatin1String
-#else
-#define U QStringLiteral
-#endif
-
-//QString Catalog::supportedMimeFilters("text/x-gettext-translation application/x-xliff application/x-linguist"); //" text/x-gettext-translation-template")
 QString Catalog::supportedFileTypes(bool includeTemplates)
 {
-    QString sep = QStringLiteral(";;");
-    QString all = i18n("All supported files (*.po *.pot *.xlf *.xliff *.ts)") + sep;
-    return all + (includeTemplates ? i18n("Gettext (*.po *.pot)") : i18n("Gettext (*.po)")) + sep + i18n("XLIFF (*.xlf *.xliff)") + sep + i18n("Linguist (*.ts)");
+    QStringList supportedTypes;
+    if (includeTemplates) {
+        supportedTypes << i18n("All supported files (*.po *.pot *.xlf *.xliff *.ts)");
+        supportedTypes << i18n("Gettext (*.po *.pot)");
+    } else {
+        supportedTypes << i18n("All supported files (*.po *.xlf *.xliff *.ts)");
+        supportedTypes << i18n("Gettext (*.po)");
+    }
+    supportedTypes << i18n("XLIFF (*.xlf *.xliff)");
+    supportedTypes << i18n("Linguist (*.ts)");
+
+    return supportedTypes.join(QLatin1String(";;"));
 }
 
-static const QString extensions[] = {U(".po"), U(".pot"), U(".xlf"), U(".xliff"), U(".ts")};
+static const QString extensions[] = {QStringLiteral(".po"), QStringLiteral(".pot"), QStringLiteral(".xlf"), QStringLiteral(".xliff"), QStringLiteral(".ts")};
 
 static const char* const xliff_states[] = {
     I18N_NOOP("New"), I18N_NOOP("Needs translation"), I18N_NOOP("Needs full localization"), I18N_NOOP("Needs adaptation"), I18N_NOOP("Translated"),
@@ -87,17 +87,16 @@ bool Catalog::extIsSupported(const QString& path)
 Catalog::Catalog(QObject *parent)
     : QUndoStack(parent)
     , d(this)
-    , m_storage(nullptr)
 {
     //cause refresh events for files modified from lokalize itself aint delivered automatically
-    connect(this, QOverload<const QString &>::of(&Catalog::signalFileSaved), Project::instance()->model(), QOverload<const QString &>::of(&ProjectModel::slotFileSaved), Qt::QueuedConnection);
+    connect(this, qOverload<const QString &>(&Catalog::signalFileSaved), Project::instance()->model(), qOverload<const QString &>(&ProjectModel::slotFileSaved), Qt::QueuedConnection);
 
     QTimer* t = &(d._autoSaveTimer);
     t->setInterval(2 * 60 * 1000);
     t->setSingleShot(false);
     connect(t, &QTimer::timeout, this, &Catalog::doAutoSave);
-    connect(this, QOverload<>::of(&Catalog::signalFileSaved), t, QOverload<>::of(&QTimer::start));
-    connect(this, QOverload<>::of(&Catalog::signalFileLoaded), t, QOverload<>::of(&QTimer::start));
+    connect(this, qOverload<>(&Catalog::signalFileSaved), t, qOverload<>(&QTimer::start));
+    connect(this, qOverload<>(&Catalog::signalFileLoaded), t, qOverload<>(&QTimer::start));
     connect(this, &Catalog::indexChanged, this, &Catalog::setAutoSaveDirty);
     connect(Project::local(), &Project::configChanged, this, &Catalog::projectConfigChanged);
 }
@@ -122,9 +121,10 @@ void Catalog::clear()
     d._lastModifiedPos = DocPosition();
     d._modifiedEntries.clear();
 
-    while (!d._altTransCatalogs.isEmpty())
-        d._altTransCatalogs.takeFirst()->deleteLater();
-
+    while (!d._altTransCatalogs.empty()) {
+        d._altTransCatalogs.front()->deleteLater();
+        d._altTransCatalogs.pop_front();
+    }
     d._altTranslations.clear();
     /*
         d.msgidDiffList.clear();
@@ -258,7 +258,7 @@ QStringList Catalog::noteAuthors() const
 
 void Catalog::attachAltTransCatalog(Catalog* altCat)
 {
-    d._altTransCatalogs.append(altCat);
+    d._altTransCatalogs.push_back(altCat);
     if (numberOfEntries() != altCat->numberOfEntries())
         qCWarning(LOKALIZE_LOG) << altCat->url() << "has different number of entries";
 }
@@ -288,7 +288,7 @@ QVector<AltTrans> Catalog::altTrans(const DocPosition& pos) const
         QString target = altCat->msgstr(pos);
         if (!target.isEmpty() && altCat->isApproved(pos)) {
             result << AltTrans();
-            result.last().target = target;
+            result.last().target = CatalogString(target);
             result.last().type = AltTrans::Reference;
             result.last().origin = altCat->url();
         }
@@ -353,11 +353,11 @@ void Catalog::updateApprovedEmptyIndexCache()
     const int limit = m_storage->size();
     while (pos.entry < limit) {
         if (m_storage->isEmpty(pos))
-            d._emptyIndex << pos.entry;
+            d._emptyIndex.push_back(pos.entry);
         if (!isApproved(pos)) {
-            d._nonApprovedIndex << pos.entry;
+            d._nonApprovedIndex.push_back(pos.entry);
             if (!m_storage->isEmpty(pos)) {
-                d._nonApprovedNonEmptyIndex << pos.entry;
+                d._nonApprovedNonEmptyIndex.push_back(pos.entry);
             }
         }
         ++(pos.entry);
@@ -624,7 +624,7 @@ bool Catalog::saveToUrl(QString localFilePath)
     if (Q_UNLIKELY(!m_storage))
         return true;
 
-    bool nameChanged = localFilePath.length();
+    bool nameChanged = !localFilePath.isEmpty();
     if (Q_LIKELY(!nameChanged))
         localFilePath = d._filePath;
 
@@ -754,7 +754,7 @@ void Catalog::flushUpdateDBBuffer()
     if (Project::instance()->targetLangCode() == targetLangCode()) {
         dbName = Project::instance()->projectID();
     } else {
-        dbName = sourceLangCode() + '-' + targetLangCode();
+        dbName = sourceLangCode() + QLatin1Char('-') + targetLangCode();
         qCInfo(LOKALIZE_LOG) << "updating" << dbName << "because target language of project db does not match" << Project::instance()->targetLangCode() << targetLangCode();
         if (!TM::DBFilesModel::instance()->m_configurations.contains(dbName)) {
             TM::OpenDBJob* openDBJob = new TM::OpenDBJob(dbName, TM::Local, true);
@@ -773,7 +773,7 @@ void Catalog::flushUpdateDBBuffer()
     if (isPlural(pos.entry))
         form = pos.form;
     updateDB(url(),
-             context(pos.entry).first(),
+             context(DocPosition(pos.entry)).first(),
              sourceWithTags(pos),
              targetWithTags(pos),
              form,
@@ -820,7 +820,7 @@ void Catalog::targetDelete(const DocPosition& pos, int count)
 bool CatalogPrivate::removeFromUntransIndexIfAppropriate(CatalogStorage* storage, const DocPosition& pos)
 {
     if ((!pos.offset) && (storage->isEmpty(pos))) {
-        _emptyIndex.removeAll(pos.entry);
+        _emptyIndex.remove(pos.entry);
         return true;
     }
     return false;
@@ -882,7 +882,7 @@ TargetState Catalog::setState(const DocPosition& pos, TargetState state)
     TargetState prevState;
     if (extendedStates) {
         prevState = m_storage->setState(pos, state);
-        d._statesIndex[prevState].removeAll(pos.entry);
+        d._statesIndex[prevState].remove(pos.entry);
         insertInList(d._statesIndex[state], pos.entry);
     } else {
         prevState = closestState(!approved, activePhaseRole());
@@ -894,8 +894,8 @@ TargetState Catalog::setState(const DocPosition& pos, TargetState state)
         if (!m_storage->isEmpty(pos))
             insertInList(d._nonApprovedNonEmptyIndex, pos.entry);
     } else {
-        d._nonApprovedIndex.removeAll(pos.entry);
-        d._nonApprovedNonEmptyIndex.removeAll(pos.entry);
+        d._nonApprovedIndex.remove(pos.entry);
+        d._nonApprovedNonEmptyIndex.remove(pos.entry);
     }
 
     Q_EMIT signalNumberOfFuzziesChanged();
@@ -947,7 +947,7 @@ bool Catalog::isModified(int entry) const
 
 
 
-int findNextInList(const QLinkedList<int>& list, int index)
+int findNextInList(const std::list<int>& list, int index)
 {
     int nextIndex = -1;
     for (int key : list) {
@@ -959,7 +959,7 @@ int findNextInList(const QLinkedList<int>& list, int index)
     return nextIndex;
 }
 
-int findPrevInList(const QLinkedList<int>& list, int index)
+int findPrevInList(const std::list<int>& list, int index)
 {
     int prevIndex = -1;
     for (int key : list) {
@@ -970,10 +970,10 @@ int findPrevInList(const QLinkedList<int>& list, int index)
     return prevIndex;
 }
 
-void insertInList(QLinkedList<int>& list, int index)
+void insertInList(std::list<int>& list, int index)
 {
-    QLinkedList<int>::Iterator it = list.begin();
-    while (it != list.end() && index > *it)
+    std::list<int>::const_iterator it = list.cbegin();
+    while (it != list.cend() && index > *it)
         ++it;
     list.insert(it, index);
 }
@@ -983,7 +983,7 @@ void Catalog::setBookmark(uint idx, bool set)
     if (set)
         insertInList(d._bookmarkIndex, idx);
     else
-        d._bookmarkIndex.removeAll(idx);
+        d._bookmarkIndex.remove(idx);
 }
 
 
@@ -1034,4 +1034,4 @@ void Catalog::setOriginalOdfFilePath(const QString& odfFilePath)
     m_storage->setOriginalOdfFilePath(odfFilePath);
 }
 
-
+#include "moc_catalog.cpp"
