@@ -13,7 +13,6 @@
 
 #include "lokalize_debug.h"
 
-//#include <resources.h>
 #include "gettextstorage.h"
 #include "catalogitem.h"
 
@@ -40,8 +39,6 @@ ConversionStatus GettextExportPlugin::save(QIODevice* device,
     QTextStream stream(device);
     stream.setCodec(codec);
 
-    //if ( m_wrapWidth == -1 ) m_wrapWidth=80;
-
     // only save header if it is not empty
     const QString& headerComment(catalog->m_header.comment());
     // ### why is this useful to have a header with an empty msgstr?
@@ -63,14 +60,10 @@ ConversionStatus GettextExportPlugin::save(QIODevice* device,
         writeKeyword(stream, QStringLiteral("msgstr"), catalog->m_header.msgstr(), false);
     }
 
-
-    const QVector<CatalogItem>& catalogEntries = catalog->m_entries;
-    int limit = catalog->numberOfEntries();
-    QStringList list;
-    for (int counter = 0; counter < limit; counter++) {
+    for (const auto & entry : std::as_const(catalog->m_entries)) {
         stream << '\n';
 
-        const CatalogItem& catalogItem = catalogEntries.at(counter);
+        const CatalogItem& catalogItem = entry;
         // write entry
         writeComment(stream, catalogItem.comment());
 
@@ -89,31 +82,19 @@ ConversionStatus GettextExportPlugin::save(QIODevice* device,
             //TODO check len of the actual stringlist??
             const int forms = catalog->numberOfPluralForms();
             for (int i = 0; i < forms; ++i) {
-                QString keyword = QStringLiteral("msgstr[") + QString::number(i) + ']';
+                const QString keyword = QStringLiteral("msgstr[") + QString::number(i) + QLatin1Char(']');
                 writeKeyword(stream, keyword, catalogItem.msgstr(i), true, catalogItem.prependEmptyForMsgstr());
             }
         }
     }
 
-#if 0
-//legacy
-    if (_saveSettings.saveObsolete)
-#endif
-    {
-        QList<QString>::const_iterator oit;
-        const QStringList& _obsolete = catalog->m_catalogExtraData;
-        oit = _obsolete.constBegin();
-        if (oit != _obsolete.constEnd()) {
-            stream << "\n" << (*oit);
-            while ((++oit) != _obsolete.constEnd())
-                stream << "\n\n" << (*oit);
-            stream << '\n';
-        }
+    for (const auto & data : std::as_const(catalog->m_catalogExtraData)) {
+        stream << '\n' << data << '\n';
     }
 
-    int i = m_trailingNewLines;
-    while (--i >= 0)
+    for (short i = 0; i <= m_trailingNewLines; ++i) {
         stream << '\n';
+    }
 
     return OK;
 }
@@ -123,8 +104,8 @@ void GettextExportPlugin::writeComment(QTextStream& stream, const QString& comme
     if (!comment.isEmpty()) {
         // We must check that each comment line really starts with a #, to avoid syntax errors
         int pos = 0;
-        for (;;) {
-            const int newpos = comment.indexOf('\n', pos, Qt::CaseInsensitive);
+        while (true) {
+            const int newpos = comment.indexOf(QLatin1Char('\n'), pos, Qt::CaseInsensitive);
             if (newpos == pos) {
                 ++pos;
                 stream << '\n';
@@ -136,10 +117,10 @@ void GettextExportPlugin::writeComment(QTextStream& stream, const QString& comme
             QString spaces; // Stored leading spaces
             for (int i = 0 ; i < len ; ++i) {
                 const QChar& ch = span[ i ];
-                if (ch == '#') {
+                if (ch == QLatin1Char('#')) {
                     stream << spaces << span.mid(i);
                     break;
-                } else if (ch == ' ' || ch == '\t') {
+                } else if (ch == QLatin1Char(' ') || ch == QLatin1Char('\t')) {
                     // We have a leading white space character, so store it temporary
                     spaces += ch;
                 } else {
@@ -167,69 +148,45 @@ void GettextExportPlugin::writeKeyword(QTextStream& stream, const QString& keywo
     }
 
     text.replace(QLatin1Char('"'), QStringLiteral("\\\""));
-#if 0
-    if (m_wrapWidth == -1) {
-        // Traditional KBabel wrapping
-        QStringList list = text.split('\n', Qt::SkipEmptyParts);
-
-        if (text.startsWith('\n'))
-            list.prepend(QString());
-
-        if (list.isEmpty())
-            list.append(QString());
-
-        if (list.count() > 1)
-            list.prepend(QString());
-
-        stream << keyword << ' ';
-
-        QStringList::const_iterator it;
-        for (it = list.constBegin(); it != list.constEnd(); ++it)
-            stream << '\"' << (*it) << "\"\n";
-        return;
-    }
-#endif
 
     if (m_wrapWidth == 0) { // Unknown special wrapping, so assume "no wrap" instead
-        // No wrapping (like Gettext's --no.wrap or -w0 )
+        // No wrapping (like Gettext's --no-wrap or -w0 )
         // we need to remove the \n characters, as they are extra characters
         QString realText(text);
-        realText.remove('\n');
+        realText.remove(QLatin1Char('\n'));
         stream << keyword << " \"" << realText << "\"\n";
         return;
     } else if (m_wrapWidth <= 3) {
         // No change in wrapping
-        QStringList list = text.split('\n');
-        if (list.count() > 1 || startedWithEmptyLine /* || keyword.length()+3+text.length()>=80*/)
+        QStringList list = text.split(QLatin1Char('\n'));
+        if (list.count() > 1 || startedWithEmptyLine)
             list.prepend(QString());
 
         stream << keyword << QStringLiteral(" ");
-        QStringList::const_iterator it;
-        for (it = list.constBegin(); it != list.constEnd(); ++it)
-            stream << QStringLiteral("\"") << (*it) << QStringLiteral("\"\n");
+
+        for (const auto & item : std::as_const(list)) {
+            stream << QStringLiteral("\"") << item << QStringLiteral("\"\n");
+        }
 
         return;
     }
 
     // lazy wrapping
-    QStringList list = text.split('\n', Qt::SkipEmptyParts);
+    QStringList list = text.split(QLatin1Char('\n'), Qt::SkipEmptyParts);
 
-    if (text.startsWith('\n'))
+    if (text.startsWith(QLatin1Char('\n')))
         list.prepend(QString());
 
     if (list.isEmpty())
         list.append(QString());
 
-    //static QRegExp breakStopReForHtml("[ >.%/:,]", Qt::CaseSensitive, QRegExp::Wildcard);
-    //static QRegExp breakStopReForText("[ .%/:,]", Qt::CaseSensitive, QRegExp::Wildcard);
-    static QRegExp breakStopReForHtml(QStringLiteral("[ >%]"), Qt::CaseSensitive, QRegExp::Wildcard);
-    static QRegExp breakStopReForText(QStringLiteral("[ &%]"), Qt::CaseSensitive, QRegExp::Wildcard);
-    QRegExp breakStopRe = containsHtml ? breakStopReForHtml : breakStopReForText;
+    const QRegExp breakStopRe = containsHtml
+                              ? QRegExp(QStringLiteral("[ >%]"), Qt::CaseSensitive, QRegExp::Wildcard)
+                              : QRegExp(QStringLiteral("[ &%]"), Qt::CaseSensitive, QRegExp::Wildcard);
 
     int max = m_wrapWidth - 2;
     bool prependedEmptyLine = false;
-    QStringList::iterator itm;
-    for (itm = list.begin(); itm != list.end(); ++itm) {
+    for (auto itm = list.begin(); itm != list.end(); ++itm) {
         if (list.count() == 1 && keyword.length() + 1 + itm->length() >= max) {
             prependedEmptyLine = true;
             itm = list.insert(itm, QString());
@@ -271,7 +228,7 @@ void GettextExportPlugin::writeKeyword(QTextStream& stream, const QString& keywo
 
     stream << keyword << QStringLiteral(" ");
 
-    QStringList::const_iterator it;
-    for (it = list.constBegin(); it != list.constEnd(); ++it)
-        stream << QStringLiteral("\"") << (*it) << QStringLiteral("\"\n");
+    for (const auto & item: std::as_const(list)) {
+        stream << QStringLiteral("\"") << item << QStringLiteral("\"\n");
+    }
 }
