@@ -14,32 +14,23 @@
 #include "version.h"
 #include "prefs_lokalize.h"
 
-#include <QProcess>
 #include <QString>
 #include <QMap>
 #include <QDomDocument>
 #include <QElapsedTimer>
 #include <QPair>
 #include <QList>
-#include <QXmlSimpleReader>
+#include <QXmlStreamReader>
 
 #include <klocalizedstring.h>
 
-#ifdef Q_OS_WIN
-#define U QLatin1String
-#else
-#define U QStringLiteral
-#endif
-
-//static const char* const noyes[]={"no","yes"};
-
-static const QString names[] = {U("source"), U("translation"), U("oldsource"), U("translatorcomment"), U("comment"), U("name"), U("numerus")};
+static const QString names[] = {QStringLiteral("source"), QStringLiteral("translation"), QStringLiteral("oldsource"), QStringLiteral("translatorcomment"), QStringLiteral("comment"), QStringLiteral("name"), QStringLiteral("numerus")};
 enum TagNames                {SourceTag, TargetTag, OldSourceTag, NoteTag, DevNoteTag, NameTag, PluralTag};
 
-static const QString attrnames[] = {U("location"), U("type"), U("obsolete")};
+static const QString attrnames[] = {QStringLiteral("location"), QStringLiteral("type"), QStringLiteral("obsolete")};
 enum AttrNames                   {LocationAttr, TypeAttr, ObsoleteAttr};
 
-static const QString attrvalues[] = {U("obsolete"), U("vanished")};
+static const QString attrvalues[] = {QStringLiteral("obsolete"), QStringLiteral("vanished")};
 enum AttValues                    {ObsoleteVal, VanishedVal};
 
 static QString protect(const QString & str)
@@ -64,11 +55,6 @@ static QString unprotect(const QString & str)
     return p;
 }
 
-TsStorage::TsStorage()
-    : CatalogStorage()
-{
-}
-
 int TsStorage::capabilities() const
 {
     return 0;//MultipleNotes;
@@ -80,14 +66,12 @@ int TsStorage::load(QIODevice* device)
 {
     QElapsedTimer chrono; chrono.start();
 
-    QXmlSimpleReader reader;
-    reader.setFeature(QStringLiteral("http://qt-project.org/xml/features/report-whitespace-only-CharData"), true);
-    reader.setFeature(QStringLiteral("http://xml.org/sax/features/namespaces"), false);
-    QXmlInputSource source(device);
+    QXmlStreamReader reader(device);
+    reader.setNamespaceProcessing(false);
 
     QString errorMsg;
-    int errorLine;//+errorColumn;
-    bool success = m_doc.setContent(&source, &reader, &errorMsg, &errorLine/*,errorColumn*/);
+    int errorLine{};//+errorColumn;
+    bool success = m_doc.setContent(&reader, false, &errorMsg, &errorLine/*,errorColumn*/);
 
     if (!success) {
         qCWarning(LOKALIZE_LOG) << "parse error" << errorMsg << errorLine;
@@ -208,6 +192,7 @@ bool TsStorage::save(QIODevice* device, bool belongsToProject)
                .replace(QStringLiteral("<numerusform><![CDATA["), QStringLiteral("<numerusform>"))
                .replace(QStringLiteral("<translation type=\"vanished\"><![CDATA["), QStringLiteral("<translation type=\"vanished\">"))
                .replace(QStringLiteral("<translation type=\"unfinished\"><![CDATA["), QStringLiteral("<translation type=\"unfinished\">"))
+               .replace(QStringLiteral("<translation type=\"obsolete\"><![CDATA["), QStringLiteral("<translation type=\"obsolete\">"))
                .replace(QStringLiteral("<translatorcomment><![CDATA["), QStringLiteral("<translatorcomment>"))
                .replace(QStringLiteral("]]></source>"), QStringLiteral("</source>"))
                .replace(QStringLiteral("]]></translation>"), QStringLiteral("</translation>"))
@@ -232,15 +217,13 @@ struct TsContentEditingData {
     enum ActionType {Get, DeleteText, InsertText, CheckLength};
 
     QString stringToInsert;
-    int pos;
-    int lengthOfStringToRemove;
+    int pos{-1};
+    int lengthOfStringToRemove{-1};
     ActionType actionType;
 
     ///Get
-    TsContentEditingData(ActionType type = Get)
-        : pos(-1)
-        , lengthOfStringToRemove(-1)
-        , actionType(type)
+    explicit TsContentEditingData(ActionType type = Get)
+        : actionType(type)
     {}
 
     ///DeleteText
@@ -262,7 +245,7 @@ struct TsContentEditingData {
 static QString doContent(QDomElement elem, int startingPos, TsContentEditingData* data);
 
 /**
- * walks through XLIFF XML and performs actions depending on TsContentEditingData:
+ * walks through TS XML and performs actions depending on TsContentEditingData:
  * - reads content
  * - deletes content, or
  * - inserts content
@@ -279,7 +262,7 @@ static QString doContent(QDomElement elem, int startingPos, TsContentEditingData
     QString result;
 
     if (elem.isNull()
-        || (!result.isEmpty() && data && data->actionType == TsContentEditingData::CheckLength))
+        || (data && data->actionType == TsContentEditingData::CheckLength))
         return QString();
 
     bool seenCDataAfterElement = false;
@@ -310,7 +293,7 @@ static QString doContent(QDomElement elem, int startingPos, TsContentEditingData
                         //qCWarning(LOKALIZE_LOG)<<"simple delete"<<localStartPos<<data->lengthOfStringToRemove;
                         c.deleteData(localStartPos, data->lengthOfStringToRemove);
                         data->actionType = TsContentEditingData::CheckLength;
-                        return QString('a');//so it exits 100%
+                        return QStringLiteral("a");//so it exits 100%
                     }
                 }
                 //END DELETE TEXT
@@ -318,7 +301,7 @@ static QString doContent(QDomElement elem, int startingPos, TsContentEditingData
                 else if (data->actionType == TsContentEditingData::InsertText) {
                     c.insertData(localStartPos, data->stringToInsert);
                     data->actionType = TsContentEditingData::CheckLength;
-                    return QString('a');//so it exits 100%
+                    return QStringLiteral("a");//so it exits 100%
                 }
                 cData = c.data();
             }
@@ -378,7 +361,7 @@ QString TsStorage::sourceWithPlurals(const DocPosition& pos, bool truncateFirstL
 {
     QString str = source(pos);
     if (truncateFirstLine) {
-        int truncatePos = str.indexOf("\n");
+        int truncatePos = str.indexOf(QLatin1Char('\n'));
         if (truncatePos != -1)
             str.truncate(truncatePos);
     }
@@ -388,7 +371,7 @@ QString TsStorage::targetWithPlurals(const DocPosition& pos, bool truncateFirstL
 {
     QString str = target(pos);
     if (truncateFirstLine) {
-        int truncatePos = str.indexOf("\n");
+        int truncatePos = str.indexOf(QLatin1Char('\n'));
         if (truncatePos != -1)
             str.truncate(truncatePos);
     }
@@ -454,7 +437,7 @@ QStringList TsStorage::sourceFiles(const DocPosition& pos) const
         QString sourcefile = elem.attribute(QStringLiteral("filename"));
         QString linenumber = elem.attribute(QStringLiteral("line"));
         if (!(sourcefile.isEmpty() && linenumber.isEmpty()))
-            result.append(sourcefile + ':' + linenumber);
+            result.append(sourcefile + QLatin1Char(':') + linenumber);
 
         elem = elem.nextSiblingElement(attrnames[LocationAttr]);
     }
@@ -568,7 +551,7 @@ QStringList TsStorage::matchData(const DocPosition& pos) const
 QString TsStorage::id(const DocPosition& pos) const
 {
     QString result = source(pos);
-    result.remove('\n');
+    result.remove(QLatin1Char('\n'));
     QStringList ctxt = context(pos);
     if (ctxt.size())
         result.prepend(ctxt.first());
@@ -585,25 +568,25 @@ bool TsStorage::isPlural(const DocPosition& pos) const
 void TsStorage::setApproved(const DocPosition& pos, bool approved)
 {
     targetInsert(pos, QString()); //adds <target> if needed
-    QDomElement target = unitForPos(pos.entry).firstChildElement(names[TargetTag]); //asking directly to bypass plural state detection
-    if (target.attribute(attrnames[TypeAttr]) == attrvalues[ObsoleteVal])
+    QDomElement targetElem = unitForPos(pos.entry).firstChildElement(names[TargetTag]); //asking directly to bypass plural state detection
+    if (targetElem.attribute(attrnames[TypeAttr]) == attrvalues[ObsoleteVal])
         return;
     if (approved)
-        target.removeAttribute(attrnames[TypeAttr]);
+        targetElem.removeAttribute(attrnames[TypeAttr]);
     else
-        target.setAttribute(attrnames[TypeAttr], QStringLiteral("unfinished"));
+        targetElem.setAttribute(attrnames[TypeAttr], QStringLiteral("unfinished"));
 }
 
 bool TsStorage::isApproved(const DocPosition& pos) const
 {
-    QDomElement target = unitForPos(pos.entry).firstChildElement(names[TargetTag]);
-    return !target.hasAttribute(attrnames[TypeAttr]) || target.attribute(attrnames[TypeAttr]) == attrvalues[VanishedVal];
+    const QDomElement targetElem = unitForPos(pos.entry).firstChildElement(names[TargetTag]);
+    return !targetElem.hasAttribute(attrnames[TypeAttr]) || targetElem.attribute(attrnames[TypeAttr]) == attrvalues[VanishedVal];
 }
 
 bool TsStorage::isObsolete(int entry) const
 {
-    QDomElement target = unitForPos(entry).firstChildElement(names[TargetTag]);
-    QString v = target.attribute(attrnames[TypeAttr]);
+    const QDomElement targetElem = unitForPos(entry).firstChildElement(names[TargetTag]);
+    const QString v = targetElem.attribute(attrnames[TypeAttr]);
     return v == attrvalues[ObsoleteVal] || v == attrvalues[VanishedVal];
 }
 
@@ -633,14 +616,14 @@ QDomElement TsStorage::unitForPos(int pos) const
 
 QDomElement TsStorage::targetForPos(DocPosition pos) const
 {
-    QDomElement unit = unitForPos(pos.entry);
+    const QDomElement unit = unitForPos(pos.entry);
     QDomElement translation = unit.firstChildElement(names[TargetTag]);
     if (!unit.hasAttribute(names[PluralTag]))
         return translation;
 
     if (pos.form == -1) pos.form = 0;
 
-    QDomNodeList forms = translation.elementsByTagName(QStringLiteral("numerusform"));
+    const QDomNodeList forms = translation.elementsByTagName(QStringLiteral("numerusform"));
     while (pos.form >= forms.size())
         translation.appendChild(unit.ownerDocument().createElement(QStringLiteral("numerusform")));
     return forms.at(pos.form).toElement();
@@ -656,9 +639,9 @@ void TsStorage::setTargetLangCode(const QString& langCode)
     m_targetLangCode = langCode;
 
     QDomElement file = m_doc.elementsByTagName(QStringLiteral("TS")).at(0).toElement();
-    if (m_targetLangCode != file.attribute(QStringLiteral("language")).replace('-', '_')) {
+    if (m_targetLangCode != file.attribute(QStringLiteral("language")).replace(QLatin1Char('-'), QLatin1Char('_'))) {
         QString l = langCode;
-        file.setAttribute(QStringLiteral("language"), l.replace('_', '-'));
+        file.setAttribute(QStringLiteral("language"), l.replace(QLatin1Char('_'), QLatin1Char('-')));
     }
 }
 
