@@ -31,20 +31,19 @@ QString enhanceLangCode(const QString& langCode)
 #include <QTextCodec>
 
 struct SpellerAndCodec {
-    Hunspell* speller;
-    QTextCodec* codec;
+    Hunspell* speller{nullptr};
+    QTextCodec* codec{nullptr};
     SpellerAndCodec(): speller(nullptr), codec(nullptr) {}
-    SpellerAndCodec(const QString& langCode);
+    explicit SpellerAndCodec(const QString& langCode);
 };
 
 SpellerAndCodec::SpellerAndCodec(const QString& langCode)
-    : speller(nullptr), codec(nullptr)
 {
 #ifdef Q_OS_MAC
-    QString dictPath = QStringLiteral("/Applications/LibreOffice.app/Contents/Resources/extensions/dict-") + langCode.leftRef(2) + '/';
+    QString dictPath = QStringLiteral("/Applications/LibreOffice.app/Contents/Resources/extensions/dict-") + langCode.leftRef(2) + QLatin1Char('/');
     if (langCode == QLatin1String("pl_PL")) dictPath = QStringLiteral("/System/Library/Spelling/");
 #elif defined(Q_OS_WIN)
-    QString dictPath = QStringLiteral("C:/Program Files (x86)/LibreOffice 5/share/extensions/dict-") + langCode.leftRef(2) + '/';
+    QString dictPath = QStringLiteral("C:/Program Files (x86)/LibreOffice 5/share/extensions/dict-") + langCode.leftRef(2) + QLatin1Char('/');
 #else
     QString dictPath = QStringLiteral("/usr/share/hunspell/");
     if (!QFileInfo::exists(dictPath))
@@ -55,7 +54,7 @@ SpellerAndCodec::SpellerAndCodec(const QString& langCode)
     if (!QFileInfo::exists(dic))
         dic = dictPath + enhanceLangCode(langCode) + QLatin1String(".dic");
     if (QFileInfo::exists(dic)) {
-        speller = new Hunspell(QString(dictPath + langCode + ".aff").toLatin1().constData(), dic.toLatin1().constData());
+        speller = new Hunspell(QString(dictPath + langCode + QLatin1String(".aff")).toLatin1().constData(), dic.toLatin1().constData());
         codec = QTextCodec::codecForName(speller->get_dic_encoding());
         if (!codec)
             codec = QTextCodec::codecForLocale();
