@@ -1,37 +1,13 @@
-/* ****************************************************************************
+/*
   This file is part of Lokalize (some bits of KBabel code were reused)
 
-  Copyright (C) 2007-2014 by Nick Shaforostoff <shafff@ukr.net>
-  Copyright (C) 1999-2000 by Matthias Kiefer <matthias.kiefer@gmx.de>
-                2001-2004 by Stanislav Visnovsky <visnovsky@kde.org>
-                2018-2019 by Simon Depiets <sdepiets@gmail.com>
+  SPDX-FileCopyrightText: 2007-2014 Nick Shaforostoff <shafff@ukr.net>
+  SPDX-FileCopyrightText: 1999-2000 Matthias Kiefer <matthias.kiefer@gmx.de>
+  SPDX-FileCopyrightText: 2001-2004 Stanislav Visnovsky <visnovsky@kde.org>
+  SPDX-FileCopyrightText: 2018-2019 Simon Depiets <sdepiets@gmail.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-
-  In addition, as a special exception, the copyright holders give
-  permission to link the code of this program with any edition of
-  the Qt library by Trolltech AS, Norway (or with modified versions
-  of Qt that use the same license as Qt), and distribute linked
-  combinations including the two.  You must obey the GNU General
-  Public License in all respects for all of the code used other than
-  Qt. If you modify this file, you may extend this exception to
-  your version of the file, but you are not obligated to do so.  If
-  you do not wish to do so, delete this exception statement from
-  your version.
-
-**************************************************************************** */
+  SPDX-License-Identifier: GPL-2.0-or-later WITH LicenseRef-Qt-Commercial-exception-1.0
+*/
 
 #include "editorview.h"
 
@@ -99,8 +75,6 @@ EditorView::EditorView(QWidget *parent, Catalog* catalog/*,keyEventHandler* kh*/
     , m_sourceTextEdit(new TranslationUnitTextEdit(catalog, DocPosition::Source, this))
     , m_targetTextEdit(new TranslationUnitTextEdit(catalog, DocPosition::Target, this))
     , m_pluralTabBar(new QTabBar(this))
-    , m_leds(nullptr)
-    , m_modifiedAfterFind(false)
 {
     m_pluralTabBar->hide();
     m_sourceTextEdit->setWhatsThis(i18n("<qt><p><b>Original String</b></p>\n"
@@ -155,7 +129,7 @@ EditorView::~EditorView()
 void EditorView::resetFindForCurrent(const DocPosition& pos)
 {
     m_modifiedAfterFind = true;
-    emit signalChanged(pos.entry);
+    Q_EMIT signalChanged(pos.entry);
 }
 
 
@@ -237,12 +211,12 @@ void EditorView::gotoEntry(DocPosition pos, int selection)
     } else if (!untrans) {
         QTextCursor t = m_targetTextEdit->textCursor();
         //what if msg starts with a tag?
-        if (Q_UNLIKELY(targetString.startsWith('<'))) {
+        if (Q_UNLIKELY(targetString.startsWith(QLatin1Char('<')))) {
             int offset = targetString.indexOf(QRegExp(QStringLiteral(">[^<]")));
             if (offset != -1)
                 t.movePosition(QTextCursor::NextCharacter, QTextCursor::MoveAnchor, offset + 1);
         } else if (Q_UNLIKELY(targetString.startsWith(TAGRANGE_IMAGE_SYMBOL))) {
-            int offset = targetString.indexOf(QRegExp(QStringLiteral("[^") + QChar(TAGRANGE_IMAGE_SYMBOL) + ']'));
+            int offset = targetString.indexOf(QRegExp(QStringLiteral("[^") + QChar(TAGRANGE_IMAGE_SYMBOL) + QLatin1Char(']')));
             if (offset != -1)
                 t.movePosition(QTextCursor::NextCharacter, QTextCursor::MoveAnchor, offset + 1);
         }
@@ -265,7 +239,7 @@ void EditorView::unwrap(TranslationUnitTextEdit* editor)
     if (!editor)
         editor = m_targetTextEdit;
 
-    QTextCursor t = editor->document()->find(QRegExp("[^(\\\\n)]$"));
+    QTextCursor t = editor->document()->find(QRegExp(QStringLiteral("[^(\\\\n)]$")));
     if (t.isNull())
         return;
 
@@ -275,7 +249,7 @@ void EditorView::unwrap(TranslationUnitTextEdit* editor)
     if (!t.atEnd())
         t.deleteChar();
 
-    QRegExp rx("[^(\\\\n)>]$");
+    QRegExp rx(QStringLiteral("[^(\\\\n)>]$"));
     //remove '\n's skipping "\\\\n"
     while (!(t = editor->document()->find(rx, t)).isNull()) {
         t.movePosition(QTextCursor::EndOfLine);
@@ -336,7 +310,7 @@ void EditorView::toggleApprovement()
 
     bool newState = !m_catalog->isApproved(m_targetTextEdit->currentPos().entry);
     SetStateCmd::push(m_catalog, m_targetTextEdit->currentPos(), newState);
-    emit signalApprovedEntryDisplayed(newState);
+    Q_EMIT signalApprovedEntryDisplayed(newState);
 }
 
 void EditorView::setState(TargetState state)
@@ -346,7 +320,7 @@ void EditorView::setState(TargetState state)
         return;
 
     SetStateCmd::instantiateAndPush(m_catalog, m_targetTextEdit->currentPos(), state);
-    emit signalApprovedEntryDisplayed(m_catalog->isApproved(m_targetTextEdit->currentPos()));
+    Q_EMIT signalApprovedEntryDisplayed(m_catalog->isApproved(m_targetTextEdit->currentPos()));
 }
 
 void EditorView::setEquivTrans(bool equivTrans)
@@ -354,4 +328,4 @@ void EditorView::setEquivTrans(bool equivTrans)
     m_catalog->push(new SetEquivTransCmd(m_catalog, m_targetTextEdit->currentPos(), equivTrans));
 }
 
-
+#include "moc_editorview.cpp"
