@@ -55,7 +55,7 @@ static QStringList doScanRecursive(const QDir& dir);
 class FileListModel: public QStringListModel
 {
 public:
-    FileListModel(QObject* parent): QStringListModel(parent) {}
+    explicit FileListModel(QObject* parent): QStringListModel(parent) {}
     QVariant data(const QModelIndex& item, int role = Qt::DisplayRole) const override;
     Qt::ItemFlags flags(const QModelIndex&) const override
     {
@@ -179,7 +179,6 @@ SearchJob::SearchJob(const QStringList& f, const SearchParams& sp, const QVector
     , searchParams(sp)
     , rules(r)
     , searchNumber(sn)
-    , m_size(0)
 {
     setAutoDelete(false);
 }
@@ -217,7 +216,7 @@ void SearchJob::run()
                     //FileSearchResult r;
                     SearchResult r;
                     r.filepath = filePath;
-                    r.docPos = pos;
+                    r.docPos = DocPos(pos);
                     if (!searchParams.sourcePattern.isEmpty() && !searchParams.invertSource)
                         r.sourcePositions << StartLen(searchParams.sourcePattern.pos(), searchParams.sourcePattern.matchedLength());
                     if (!searchParams.targetPattern.isEmpty() && !searchParams.invertTarget)
@@ -266,7 +265,7 @@ void MassReplaceJob::run()
 {
     QMultiHash<QString, int> map;
     for (int i = 0; i < searchResults.count(); ++i)
-        map.insertMulti(searchResults.at(i).filepath, i);
+        map.insert(searchResults.at(i).filepath, i);
 
     const auto filepaths = map.keys();
     for (const QString& filepath : filepaths) {
@@ -297,7 +296,7 @@ void MassReplaceJob::run()
                     qCWarning(LOKALIZE_LOG) << "skipping replace because matched text contains markup" << s.string;
                 }
 
-                if (pos > s.string.length() || replaceWhat.pattern().startsWith('^'))
+                if (pos > s.string.length() || replaceWhat.pattern().startsWith(QLatin1Char('^')))
                     break;
 
                 pos = replaceWhat.indexIn(s.string, pos);
@@ -419,8 +418,6 @@ FileSearchTab::FileSearchTab(QWidget *parent)
     : LokalizeSubwindowBase2(parent)
 //    , m_proxyModel(new TMResultsSortFilterProxyModel(this))
     , m_model(new FileSearchModel(this))
-    , m_lastSearchNumber(0)
-    , m_dbusId(-1)
 {
     setWindowTitle(i18nc("@title:window", "Search and replace in files"));
     setAcceptDrops(true);
@@ -432,7 +429,7 @@ FileSearchTab::FileSearchTab(QWidget *parent)
 
 
     QShortcut* sh = new QShortcut(Qt::CTRL + Qt::Key_L, this);
-    connect(sh, &QShortcut::activated, ui_fileSearchOptions->querySource, QOverload<>::of(&QLineEdit::setFocus));
+    connect(sh, &QShortcut::activated, ui_fileSearchOptions->querySource, qOverload<>(&QLineEdit::setFocus));
     setFocusProxy(ui_fileSearchOptions->querySource);
 
     sh = new QShortcut(Qt::Key_Escape, this, SLOT(stopSearch()), nullptr, Qt::WidgetWithChildrenShortcut);
@@ -513,7 +510,7 @@ FileSearchTab::FileSearchTab(QWidget *parent)
     //m_searchFileListView->hide();
     addDockWidget(Qt::RightDockWidgetArea, m_searchFileListView);
     srf->addAction(QStringLiteral("showfilelist_action"), m_searchFileListView->toggleViewAction());
-    connect(m_searchFileListView, &SearchFileListView::fileOpenRequested, this, QOverload<const QString &, const bool>::of(&FileSearchTab::fileOpenRequested));
+    connect(m_searchFileListView, &SearchFileListView::fileOpenRequested, this, qOverload<const QString &, const bool>(&FileSearchTab::fileOpenRequested));
 
     m_massReplaceView = new MassReplaceView(this);
     addDockWidget(Qt::RightDockWidgetArea, m_massReplaceView);
@@ -522,7 +519,6 @@ FileSearchTab::FileSearchTab(QWidget *parent)
     connect(m_massReplaceView, &MassReplaceView::replaceRequested, this, &FileSearchTab::massReplace);
     //m_massReplaceView->hide();
 
-    m_qaView = new QaView(this);
     m_qaView->hide();
     addDockWidget(Qt::RightDockWidgetArea, m_qaView);
     srf->addAction(QStringLiteral("showqa_action"), m_qaView->toggleViewAction());
@@ -607,11 +603,9 @@ void FileSearchTab::performSearch()
 
 void FileSearchTab::stopSearch()
 {
-#if QT_VERSION >= 0x050500
-    int i = m_runningJobs.size();
-    while (--i >= 0)
-        QThreadPool::globalInstance()->tryTake(m_runningJobs.at(i));
-#endif
+    for (auto job : qAsConst(m_runningJobs)) {
+        [[maybe_unused]] const bool result = QThreadPool::globalInstance()->tryTake(job);
+    }
     m_runningJobs.clear();
 }
 
@@ -709,7 +703,7 @@ static QStringList doScanRecursive(const QDir& dir)
     QStringList filters = Catalog::supportedExtensions();
     i = filters.size();
     while (--i >= 0)
-        filters[i].prepend('*');
+        filters[i].prepend(QLatin1Char('*'));
     QStringList files(dir.entryList(filters, QDir::Files | QDir::NoDotAndDotDot | QDir::Readable));
     i = files.size();
 
@@ -909,7 +903,7 @@ QString FileSearchTab::dbusObjectPath()
     return FILESEARCH_PATH + QString::number(m_dbusId);
 }
 
-bool FileSearchTab::findGuiTextPackage(QString text, QString package)
+bool FileSearchTab::findGuiTextPackage(QString text, [[maybe_unused]] QString package)
 {
     setSourceQuery(text);
     performSearch();
@@ -918,4 +912,4 @@ bool FileSearchTab::findGuiTextPackage(QString text, QString package)
 }
 //END DBus interface
 
-
+#include "moc_filesearchtab.cpp"
