@@ -22,10 +22,6 @@ LanguageToolManager::LanguageToolManager(QObject *parent)
     mNetworkAccessManager->enableStrictTransportSecurityStore(true);
 }
 
-LanguageToolManager::~LanguageToolManager()
-{
-}
-
 LanguageToolManager *LanguageToolManager::self()
 {
     static LanguageToolManager s_self;
@@ -44,3 +40,5 @@ QString LanguageToolManager::languageToolCheckPath() const
             QStringLiteral("https://languagetool.org/api/v2")
            ) + QStringLiteral("/check");
 }
+
+#include "moc_languagetoolmanager.cpp"
