@@ -14,18 +14,9 @@ LanguageToolResultJob::LanguageToolResultJob(QObject *parent)
 {
 }
 
-LanguageToolResultJob::~LanguageToolResultJob()
+static bool containsOnlySpaceChars(const QString &text)
 {
-}
-
-static bool hasNotEmptyText(const QString &text)
-{
-    for (int i = 0; i < text.length(); ++i) {
-        if (!text.at(i).isSpace()) {
-            return true;
-        }
-    }
-    return false;
+    return !text.trimmed().isEmpty();
 }
 
 bool LanguageToolResultJob::canStart() const
@@ -38,7 +29,7 @@ LanguageToolResultJob::JobError LanguageToolResultJob::canStartError() const
     if (!mNetworkAccessManager) {
         return LanguageToolResultJob::JobError::NetworkManagerNotDefined;
     }
-    if (!hasNotEmptyText(mText)) {
+    if (containsOnlySpaceChars(mText)) {
         return LanguageToolResultJob::JobError::EmptyText;
     }
     if (mUrl.isEmpty()) {
@@ -87,8 +78,8 @@ void LanguageToolResultJob::slotCheckGrammarFinished()
     if (reply) {
         const QByteArray data = reply->readAll();
         Q_EMIT finished(QString::fromUtf8(data));
+        reply->deleteLater();
     }
-    reply->deleteLater();
     deleteLater();
 }
 
@@ -146,3 +137,5 @@ void LanguageToolResultJob::setText(const QString &text)
 {
     mText = text;
 }
+
+#include "moc_languagetoolresultjob.cpp"
