@@ -1,26 +1,11 @@
-/* ****************************************************************************
+/*
   This file is part of Lokalize
 
-  Copyright (C) 2008-2015 by Nick Shaforostoff <shafff@ukr.net>
-                2018-2019 by Simon Depiets <sdepiets@gmail.com>
+  SPDX-FileCopyrightText: 2008-2015 Nick Shaforostoff <shafff@ukr.net>
+  SPDX-FileCopyrightText: 2018-2019 Simon Depiets <sdepiets@gmail.com>
 
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License as
-  published by the Free Software Foundation; either version 2 of
-  the License or (at your option) version 3 or any later version
-  accepted by the membership of KDE e.V. (or its successor approved
-  by the membership of KDE e.V.), which shall act as a proxy
-  defined in Section 14 of version 3 of the license.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program.  If not, see <http://www.gnu.org/licenses/>.
-
-**************************************************************************** */
+  SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+*/
 
 #include "lokalizemainwindow.h"
 
@@ -38,7 +23,6 @@
 
 #include "project.h"
 #include "projectmodel.h"
-#include "projectlocal.h"
 #include "prefs.h"
 
 #include "tools/widgettextcaptureconfig.h"
@@ -54,10 +38,10 @@
 #include <KStandardShortcut>
 #include <KRecentFilesAction>
 #include <KXMLGUIFactory>
-#include <kross/core/action.h>
 
 
 #include <QMenu>
+#include <QTabBar>
 #include <QActionGroup>
 #include <QMdiSubWindow>
 #include <QMdiArea>
@@ -72,14 +56,10 @@
 LokalizeMainWindow::LokalizeMainWindow()
     : KXmlGuiWindow()
     , m_mdiArea(new LokalizeMdiArea)
-    , m_prevSubWindow(nullptr)
-    , m_projectSubWindow(nullptr)
-    , m_translationMemorySubWindow(nullptr)
     , m_editorActions(new QActionGroup(this))
     , m_managerActions(new QActionGroup(this))
     , m_spareEditor(new EditorTab(this, false))
     , m_multiEditorAdaptor(new MultiEditorAdaptor(m_spareEditor))
-    , m_projectScriptingPlugin(nullptr)
 {
     m_spareEditor->hide();
     m_mdiArea->setViewMode(QMdiArea::TabbedView);
@@ -95,7 +75,7 @@ LokalizeMainWindow::LokalizeMainWindow()
     //prevent relayout of dockwidgets
     m_mdiArea->setOption(QMdiArea::DontMaximizeSubWindowOnActivation, true);
 
-    connect(Project::instance(), QOverload<const QString &, const bool>::of(&Project::fileOpenRequested), this, QOverload<QString, const bool>::of(&LokalizeMainWindow::fileOpen_), Qt::QueuedConnection);
+    connect(Project::instance(), qOverload<const QString &, const bool>(&Project::fileOpenRequested), this, qOverload<QString, const bool>(&LokalizeMainWindow::fileOpen_), Qt::QueuedConnection);
     connect(Project::instance(), &Project::configChanged, this, &LokalizeMainWindow::projectSettingsChanged);
     connect(Project::instance(), &Project::closed, this, &LokalizeMainWindow::closeProject);
     showProjectOverview();
@@ -126,7 +106,7 @@ void LokalizeMainWindow::initLater()
         slotSubWindowActivated(m_projectSubWindow);
 
     if (!Project::instance()->isTmSupported()) {
-        KNotification* notification = new KNotification("NoSqlModulesAvailable");
+        KNotification* notification = new KNotification(QStringLiteral("NoSqlModulesAvailable"));
         notification->setWidget(this);
         notification->setText(i18nc("@info", "No Qt Sql modules were found. Translation memory will not work."));
         notification->sendEvent();
@@ -146,14 +126,13 @@ LokalizeMainWindow::~LokalizeMainWindow()
     m_multiEditorAdaptor->deleteLater();
 
     //Disconnect the signals pointing to this MainWindow object
-    QMdiSubWindow* sw;
     for (int i = 0; i < m_fileToEditor.values().count(); i++) {
-        sw = m_fileToEditor.values().at(i);
+        QMdiSubWindow* sw = m_fileToEditor.values().at(i);
         disconnect(sw, &QMdiSubWindow::destroyed, this, &LokalizeMainWindow::editorClosed);
         EditorTab* w = static_cast<EditorTab*>(sw->widget());
         disconnect(w, &EditorTab::aboutToBeClosed, this, &LokalizeMainWindow::resetMultiEditorAdaptor);
-        disconnect(w, QOverload<const QString &, const QString &, const QString &, const bool>::of(&EditorTab::fileOpenRequested), this, QOverload<const QString &, const QString &, const QString &, const bool>::of(&LokalizeMainWindow::fileOpen));
-        disconnect(w, QOverload<const QString &, const QString &>::of(&EditorTab::tmLookupRequested), this, QOverload<const QString &, const QString &>::of(&LokalizeMainWindow::lookupInTranslationMemory));
+        disconnect(w, qOverload<const QString &, const QString &, const QString &, const bool>(&EditorTab::fileOpenRequested), this, qOverload<const QString &, const QString &, const QString &, const bool>(&LokalizeMainWindow::fileOpen));
+        disconnect(w, qOverload<const QString &, const QString &>(&EditorTab::tmLookupRequested), this, qOverload<const QString &, const QString &>(&LokalizeMainWindow::lookupInTranslationMemory));
     }
 
     qCWarning(LOKALIZE_LOG) << "MainWindow destroyed";
@@ -174,56 +153,24 @@ void LokalizeMainWindow::slotSubWindowActivated(QMdiSubWindow* w)
         guiFactory()->removeClient(prevEditor->guiClient());
         prevEditor->statusBarItems.unregisterStatusBar();
 
-        if (qobject_cast<EditorTab*>(prevEditor)) {
-            EditorTab* w = static_cast<EditorTab*>(prevEditor);
-            EditorState state = w->state();
+        if (auto win = qobject_cast<EditorTab*>(prevEditor)) {
+            EditorState state = win->state();
             m_lastEditorState = state.dockWidgets.toBase64();
         }
-        /*
-
-        QMenu* projectActions=static_cast<QMenu*>(factory()->container("project_actions",this));
-        QList<QAction*> actionz=projectActions->actions();
-
-        int i=actionz.size();
-        //projectActions->menuAction()->setVisible(i);
-        //qCWarning(LOKALIZE_LOG)<<"adding object"<<actionz.at(0);
-        while(--i>=0)
-        {
-            disconnect(w, SIGNAL(signalNewEntryDisplayed()),actionz.at(i),SLOT(signalNewEntryDisplayed()));
-            //static_cast<Kross::Action*>(actionz.at(i))->addObject(static_cast<EditorWindow*>( editor )->adaptor(),"Editor",Kross::ChildrenInterface::AutoConnectSignals);
-            //static_cast<Kross::Action*>(actionz.at(i))->trigger();
-        }
-        }
-        */
     }
     LokalizeSubwindowBase* editor = static_cast<LokalizeSubwindowBase2*>(w->widget());
 
     editor->reloadUpdatedXML();
-    if (qobject_cast<EditorTab*>(editor)) {
-        EditorTab* w = static_cast<EditorTab*>(editor);
-        w->setProperFocus();
+    if (auto win = qobject_cast<EditorTab*>(editor)) {
+        win->setProperFocus();
 
-        EditorState state = w->state();
+        EditorState state = win->state();
         m_lastEditorState = state.dockWidgets.toBase64();
 
-        m_multiEditorAdaptor->setEditorTab(w);
-//         connect(m_multiEditorAdaptor,SIGNAL(srcFileOpenRequested(QString,int)),this,SLOT(showTM()));
-        /*
-                QMenu* projectActions=static_cast<QMenu*>(factory()->container("project_actions",this));
-                QList<QAction*> actionz=projectActions->actions();
-
-                int i=actionz.size();
-                //projectActions->menuAction()->setVisible(i);
-                //qCWarning(LOKALIZE_LOG)<<"adding object"<<actionz.at(0);
-                while(--i>=0)
-                {
-                    connect(w, SIGNAL(signalNewEntryDisplayed()),actionz.at(i),SLOT(signalNewEntryDisplayed()));
-                    //static_cast<Kross::Action*>(actionz.at(i))->addObject(static_cast<EditorWindow*>( editor )->adaptor(),"Editor",Kross::ChildrenInterface::AutoConnectSignals);
-                    //static_cast<Kross::Action*>(actionz.at(i))->trigger();
-                }*/
+        m_multiEditorAdaptor->setEditorTab(win);
 
         QTabBar* tw = m_mdiArea->findChild<QTabBar*>();
-        if (tw) tw->setTabToolTip(tw->currentIndex(), w->currentFilePath());
+        if (tw) tw->setTabToolTip(tw->currentIndex(), win->currentFilePath());
 
         Q_EMIT editorActivated();
     } else if (w == m_projectSubWindow && m_projectSubWindow) {
@@ -267,7 +214,7 @@ EditorTab* LokalizeMainWindow::fileOpen_(QString filePath, const bool setAsActiv
 }
 EditorTab* LokalizeMainWindow::fileOpen(QString filePath, int entry, bool setAsActive, const QString& mergeFile, bool silent)
 {
-    if (filePath.length()) {
+    if (!filePath.isEmpty()) {
         FileToEditor::const_iterator it = m_fileToEditor.constFind(filePath);
         if (it != m_fileToEditor.constEnd()) {
             qCWarning(LOKALIZE_LOG) << "already opened:" << filePath;
@@ -283,14 +230,14 @@ EditorTab* LokalizeMainWindow::fileOpen(QString filePath, int entry, bool setAsA
 
     QMdiSubWindow* sw = nullptr;
     //create QMdiSubWindow BEFORE fileOpen() because it causes some strange QMdiArea behaviour otherwise
-    if (filePath.length())
+    if (!filePath.isEmpty())
         sw = m_mdiArea->addSubWindow(w);
 
     QString suggestedDirPath;
     QMdiSubWindow* activeSW = m_mdiArea->currentSubWindow();
     if (activeSW && qobject_cast<LokalizeSubwindowBase*>(activeSW->widget())) {
         QString fp = static_cast<LokalizeSubwindowBase*>(activeSW->widget())->currentFilePath();
-        if (fp.length()) suggestedDirPath = QFileInfo(fp).absolutePath();
+        if (!fp.isEmpty()) suggestedDirPath = QFileInfo(fp).absolutePath();
     }
 
     if (!w->fileOpen(filePath, suggestedDirPath, m_fileToEditor, silent)) {
@@ -332,10 +279,10 @@ EditorTab* LokalizeMainWindow::fileOpen(QString filePath, int entry, bool setAsA
 
     connect(sw, &QMdiSubWindow::destroyed, this, &LokalizeMainWindow::editorClosed);
     connect(w, &EditorTab::aboutToBeClosed, this, &LokalizeMainWindow::resetMultiEditorAdaptor);
-    connect(w, QOverload<const QString &, const QString &, const QString &, const bool>::of(&EditorTab::fileOpenRequested), this, QOverload<const QString &, const QString &, const QString &, const bool>::of(&LokalizeMainWindow::fileOpen));
-    connect(w, QOverload<const QString &, const QString &>::of(&EditorTab::tmLookupRequested), this, QOverload<const QString &, const QString &>::of(&LokalizeMainWindow::lookupInTranslationMemory));
+    connect(w, qOverload<const QString &, const QString &, const QString &, const bool>(&EditorTab::fileOpenRequested), this, qOverload<const QString &, const QString &, const QString &, const bool>(&LokalizeMainWindow::fileOpen));
+    connect(w, qOverload<const QString &, const QString &>(&EditorTab::tmLookupRequested), this, qOverload<const QString &, const QString &>(&LokalizeMainWindow::lookupInTranslationMemory));
 
-    QStringRef fnSlashed = filePath.midRef(filePath.lastIndexOf('/'));
+    QStringRef fnSlashed = filePath.midRef(filePath.lastIndexOf(QLatin1Char('/')));
     FileToEditor::const_iterator i = m_fileToEditor.constBegin();
     while (i != m_fileToEditor.constEnd()) {
         if (i.key().endsWith(fnSlashed)) {
@@ -385,10 +332,10 @@ QObject* LokalizeMainWindow::projectOverview()
         m_projectSubWindow = m_mdiArea->addSubWindow(w);
         w->showMaximized();
         m_projectSubWindow->showMaximized();
-        connect(w, QOverload<const QString &, const bool>::of(&ProjectTab::fileOpenRequested), this, QOverload<QString, const bool>::of(&LokalizeMainWindow::fileOpen_));
-        connect(w, QOverload<QString>::of(&ProjectTab::projectOpenRequested), this, QOverload<QString>::of(&LokalizeMainWindow::openProject));
-        connect(w, QOverload<>::of(&ProjectTab::projectOpenRequested), this, QOverload<>::of(&LokalizeMainWindow::openProject));
-        connect(w, QOverload<const QStringList &>::of(&ProjectTab::searchRequested), this, QOverload<const QStringList &>::of(&LokalizeMainWindow::addFilesToSearch));
+        connect(w, qOverload<const QString &, const bool>(&ProjectTab::fileOpenRequested), this, qOverload<QString, const bool>(&LokalizeMainWindow::fileOpen_));
+        connect(w, qOverload<QString>(&ProjectTab::projectOpenRequested), this, qOverload<QString>(&LokalizeMainWindow::openProject));
+        connect(w, qOverload<>(&ProjectTab::projectOpenRequested), this, qOverload<>(&LokalizeMainWindow::openProject));
+        connect(w, qOverload<const QStringList &>(&ProjectTab::searchRequested), this, qOverload<const QStringList &>(&LokalizeMainWindow::addFilesToSearch));
     }
     if (m_mdiArea->currentSubWindow() == m_projectSubWindow)
         return m_projectSubWindow->widget();
@@ -413,7 +360,7 @@ TM::TMTab* LokalizeMainWindow::showTM()
         m_translationMemorySubWindow = m_mdiArea->addSubWindow(w);
         w->showMaximized();
         m_translationMemorySubWindow->showMaximized();
-        connect(w, QOverload<const QString &, const QString &, const QString &, const bool>::of(&TM::TMTab::fileOpenRequested), this, QOverload<const QString &, const QString &, const QString &, const bool>::of(&LokalizeMainWindow::fileOpen));
+        connect(w, qOverload<const QString &, const QString &, const QString &, const bool>(&TM::TMTab::fileOpenRequested), this, qOverload<const QString &, const QString &, const QString &, const bool>(&LokalizeMainWindow::fileOpen));
     }
 
     m_mdiArea->setActiveSubWindow(m_translationMemorySubWindow);
@@ -429,16 +376,16 @@ FileSearchTab* LokalizeMainWindow::showFileSearch(bool activate)
         m_fileSearchSubWindow = m_mdiArea->addSubWindow(w);
         w->showMaximized();
         m_fileSearchSubWindow->showMaximized();
-        connect(w, QOverload<const QString &, DocPosition, int, const bool>::of(&FileSearchTab::fileOpenRequested), this, QOverload<const QString &, DocPosition, int, const bool>::of(&LokalizeMainWindow::fileOpen));
-        connect(w, QOverload<const QString &, const bool>::of(&FileSearchTab::fileOpenRequested), this, QOverload<QString, const bool>::of(&LokalizeMainWindow::fileOpen_));
+        connect(w, qOverload<const QString &, DocPosition, int, const bool>(&FileSearchTab::fileOpenRequested), this, qOverload<const QString &, DocPosition, int, const bool>(&LokalizeMainWindow::fileOpen));
+        connect(w, qOverload<const QString &, const bool>(&FileSearchTab::fileOpenRequested), this, qOverload<QString, const bool>(&LokalizeMainWindow::fileOpen_));
     }
 
     if (activate) {
         m_mdiArea->setActiveSubWindow(m_fileSearchSubWindow);
         if (precedingEditor) {
-            if (precedingEditor->selectionInSource().length())
+            if (!precedingEditor->selectionInSource().isEmpty())
                 static_cast<FileSearchTab*>(m_fileSearchSubWindow->widget())->setSourceQuery(precedingEditor->selectionInSource());
-            if (precedingEditor->selectionInTarget().length())
+            if (!precedingEditor->selectionInTarget().isEmpty())
                 static_cast<FileSearchTab*>(m_fileSearchSubWindow->widget())->setTargetQuery(precedingEditor->selectionInTarget());
         }
     }
@@ -475,7 +422,7 @@ void LokalizeMainWindow::setupActions()
 
     setStandardToolBarMenuEnabled(true);
 
-    QAction *action;
+    QAction *action{nullptr};
     KActionCollection* ac = actionCollection();
     KActionCategory* actionCategory;
     KActionCategory* file = new KActionCategory(i18nc("@title actions category", "File"), ac);
@@ -528,7 +475,7 @@ void LokalizeMainWindow::setupActions()
     ADD_ACTION_SHORTCUT("tools_tm", i18nc("@action:inmenu", "Translation memory"), Qt::Key_F7)
     connect(action, &QAction::triggered, this, &LokalizeMainWindow::showTM);
 
-    action = tm->addAction("tools_tm_manage", project, SLOT(showTMManager()));
+    action = tm->addAction(QStringLiteral("tools_tm_manage"), project, SLOT(showTMManager()));
     action->setText(i18nc("@action:inmenu", "Manage translation memories"));
 
 //Project
@@ -547,15 +494,15 @@ void LokalizeMainWindow::setupActions()
 
     action = proj->addAction(QStringLiteral("project_open"), this, SLOT(openProject()));
     action->setText(i18nc("@action:inmenu", "Open project..."));
-    action->setIcon(QIcon::fromTheme("project-open"));
+    action->setIcon(QIcon::fromTheme(QStringLiteral("project-open")));
 
     action = proj->addAction(QStringLiteral("project_close"), this, SLOT(closeProject()));
     action->setText(i18nc("@action:inmenu", "Close project"));
-    action->setIcon(QIcon::fromTheme("project-close"));
+    action->setIcon(QIcon::fromTheme(QStringLiteral("project-close")));
 
     m_openRecentProjectAction = new KRecentFilesAction(i18nc("@action:inmenu", "Open recent project"), this);
     action = proj->addAction(QStringLiteral("project_open_recent"), m_openRecentProjectAction);
-    connect(m_openRecentProjectAction, QOverload<const QUrl &>::of(&KRecentFilesAction::urlSelected), this, QOverload<const QUrl &>::of(&LokalizeMainWindow::openProject));
+    connect(m_openRecentProjectAction, qOverload<const QUrl &>(&KRecentFilesAction::urlSelected), this, qOverload<const QUrl &>(&LokalizeMainWindow::openProject));
 
     //Qt::QueuedConnection: defer until event loop is running to eliminate QWidgetPrivate::showChildren(bool) startup crash
     connect(Project::instance(), &Project::loaded, this, &LokalizeMainWindow::projectLoaded, Qt::QueuedConnection);
@@ -655,7 +602,7 @@ void LokalizeMainWindow::saveProjectState(KConfigGroup& stateGroup)
 
 
     KConfig config;
-    KConfigGroup projectStateGroup(&config, "State-" + Project::instance()->path());
+    KConfigGroup projectStateGroup(&config, QStringLiteral("State-") + Project::instance()->path());
     projectStateGroup.writeEntry("Active", activeSWIndex);
     projectStateGroup.writeEntry("Files", files);
     projectStateGroup.writeEntry("MergeFiles", mergeFiles);
@@ -670,9 +617,9 @@ void LokalizeMainWindow::saveProjectState(KConfigGroup& stateGroup)
 
 
     QString nameSpecifier = Project::instance()->path();
-    if (!nameSpecifier.isEmpty()) nameSpecifier.prepend('-');
+    if (!nameSpecifier.isEmpty()) nameSpecifier.prepend(QLatin1Char('-'));
     KConfig* c = stateGroup.isValid() ? stateGroup.config() : &config;
-    m_openRecentFileAction->saveEntries(KConfigGroup(c, "RecentFiles" + nameSpecifier));
+    m_openRecentFileAction->saveEntries(KConfigGroup(c, QStringLiteral("RecentFiles") + nameSpecifier));
     m_openRecentProjectAction->saveEntries(KConfigGroup(&config, "RecentProjects"));
 }
 
@@ -699,13 +646,13 @@ void LokalizeMainWindow::projectLoaded()
     KConfig config;
 
     QString nameSpecifier = projectPath;
-    if (!nameSpecifier.isEmpty()) nameSpecifier.prepend('-');
-    m_openRecentFileAction->loadEntries(KConfigGroup(&config, "RecentFiles" + nameSpecifier));
+    if (!nameSpecifier.isEmpty()) nameSpecifier.prepend(QLatin1Char('-'));
+    m_openRecentFileAction->loadEntries(KConfigGroup(&config, QLatin1String("RecentFiles") + nameSpecifier));
 
 
     //if project isn't loaded, still restore opened files from "State-"
     KConfigGroup stateGroup(&config, "State");
-    KConfigGroup projectStateGroup(&config, "State-" + projectPath);
+    KConfigGroup projectStateGroup(&config, QLatin1String("State-") + projectPath);
 
     QStringList files;
     QStringList mergeFiles;
@@ -743,9 +690,9 @@ void LokalizeMainWindow::projectLoaded()
         qCDebug(LOKALIZE_LOG) << "failedFiles" << failedFiles;
 //         KMessageBox::error(this, i18nc("@info","Error opening the following files:")+
 //                                 "<br><il><li><filename>"+failedFiles.join("</filename></li><li><filename>")+"</filename></li></il>" );
-        KNotification* notification = new KNotification("FilesOpenError");
+        KNotification* notification = new KNotification(QStringLiteral("FilesOpenError"));
         notification->setWidget(this);
-        notification->setText(i18nc("@info", "Error opening the following files:\n\n") + "<filename>" + failedFiles.join("</filename><br><filename>") + "</filename>");
+        notification->setText(i18nc("@info", "Error opening the following files:\n\n") + QStringLiteral("<filename>") + failedFiles.join(QLatin1String("</filename><br><filename>")) + QStringLiteral("</filename>"));
         notification->sendEvent();
     }
 
@@ -761,8 +708,6 @@ void LokalizeMainWindow::projectLoaded()
     }
 
     projectSettingsChanged();
-
-    QTimer::singleShot(0, this, &LokalizeMainWindow::loadProjectScripts);
 }
 
 void LokalizeMainWindow::projectSettingsChanged()
@@ -782,103 +727,6 @@ void LokalizeMainWindow::widgetTextCapture()
 
 //#include "plugin.h"
 #include "mainwindowadaptor.h"
-#include <kross/core/actioncollection.h>
-#include <kross/core/manager.h>
-
-using namespace Kross;
-
-class MyScriptingPlugin: public Kross::ScriptingPlugin
-{
-public:
-    MyScriptingPlugin(QObject* lokalize, QObject* editor)
-        : Kross::ScriptingPlugin(lokalize)
-    {
-        addObject(lokalize, "Lokalize");
-        addObject(Project::instance(), "Project");
-        addObject(editor, "Editor");
-        setXMLFile("scriptsui.rc", true);
-    }
-    ~MyScriptingPlugin() {}
-};
-
-#define PROJECTRCFILE "scripts.rc"
-#define PROJECTRCFILEDIR  Project::instance()->projectDir()+"/lokalize-scripts"
-#define PROJECTRCFILEPATH Project::instance()->projectDir()+"/lokalize-scripts" "/" PROJECTRCFILE
-//TODO be lazy creating scripts dir
-ProjectScriptingPlugin::ProjectScriptingPlugin(QObject* lokalize, QObject* editor)
-    : Kross::ScriptingPlugin(Project::instance()->kind(),
-                             PROJECTRCFILEPATH,
-                             Project::instance()->kind(), lokalize)
-{
-    if (Project::instance()->projectDir().isEmpty())
-        return;
-
-    QString filepath = PROJECTRCFILEPATH;
-
-    // Remove directory "scripts.rc" if it is empty. It could be
-    // mistakenly created by Lokalize 15.04.x.
-    if (QFileInfo(filepath).isDir() && !QDir().rmdir(filepath)) {
-        qCCritical(LOKALIZE_LOG) << "Failed to remove directory" << filepath <<
-                                 "to create scripting configuration file with at the same path. " <<
-                                 "The directory may be not empty.";
-        return;
-    }
-
-    if (!QFile::exists(filepath)) {
-        QDir().mkdir(QFileInfo(filepath).dir().path());
-        QFile f(filepath);
-        if (!f.open(QIODevice::WriteOnly))
-            return;
-        QTextStream out(&f);
-        out << "<!-- see help for the syntax -->";
-        f.close();
-    }
-
-    //qCWarning(LOKALIZE_LOG)<<Kross::Manager::self().hasInterpreterInfo("python");
-    addObject(lokalize, QLatin1String("Lokalize"), ChildrenInterface::AutoConnectSignals);
-    addObject(Project::instance(), QLatin1String("Project"), ChildrenInterface::AutoConnectSignals);
-    addObject(editor, QLatin1String("Editor"), ChildrenInterface::AutoConnectSignals);
-    setXMLFile(QLatin1String("scriptsui.rc"), true);
-}
-
-void ProjectScriptingPlugin::setDOMDocument(const QDomDocument &document, bool merge)
-{
-    Kross::ScriptingPlugin::setDOMDocument(document, merge);
-    QTimer::singleShot(0, this, &ProjectScriptingPlugin::doAutoruns);
-}
-
-void ProjectScriptingPlugin::doAutoruns()
-{
-    Kross::ActionCollection* collection = Kross::Manager::self().actionCollection()->collection(Project::instance()->kind());
-    if (!collection) return;
-    const auto collections = collection->collections();
-    for (const QString &collectionname : collections) {
-        Kross::ActionCollection* c = collection->collection(collectionname);
-        if (!c->isEnabled()) continue;
-
-        const auto actions = c->actions();
-        for (Kross::Action* action : actions) {
-            if (action->property("autorun").toBool())
-                action->trigger();
-            if (action->property("first-run").toBool() && Project::local()->firstRun())
-                action->trigger();
-        }
-    }
-}
-
-ProjectScriptingPlugin::~ProjectScriptingPlugin()
-{
-    Kross::ActionCollection* collection = Kross::Manager::self().actionCollection()->collection(Project::instance()->kind());
-    if (!collection) return;
-
-    QString scriptsrc = PROJECTRCFILE;
-    QDir rcdir(PROJECTRCFILEDIR);
-    qCDebug(LOKALIZE_LOG) << rcdir.entryList(QStringList("*.rc"), QDir::Files);
-    const auto rcs = QDir(PROJECTRCFILEDIR).entryList(QStringList("*.rc"), QDir::Files);
-    for (const QString& rc : rcs)
-        if (rc != scriptsrc)
-            qCWarning(LOKALIZE_LOG) << rc << collection->readXmlFile(rcdir.absoluteFilePath(rc));
-}
 
 /*
 void LokalizeMainWindow::checkForProjectAlreadyOpened()
@@ -903,10 +751,6 @@ void LokalizeMainWindow::registerDBusAdaptor()
     QDBusConnection::sessionBus().registerObject(QLatin1String("/ThisIsWhatYouWant"), this);
 
     //qCWarning(LOKALIZE_LOG)<<QDBusConnection::sessionBus().interface()->registeredServiceNames().value();
-#ifndef Q_OS_MAC
-    //TODO really fix!!!
-    guiFactory()->addClient(new MyScriptingPlugin(this, m_multiEditorAdaptor));
-#endif
 
     //QMenu* projectActions=static_cast<QMenu*>(factory()->container("project_actions",this));
 
@@ -917,24 +761,6 @@ void LokalizeMainWindow::registerDBusAdaptor()
     */
 }
 
-void LokalizeMainWindow::loadProjectScripts()
-{
-    if (m_projectScriptingPlugin) {
-        guiFactory()->removeClient(m_projectScriptingPlugin);
-        delete m_projectScriptingPlugin;
-    }
-
-    //a HACK to get new .rc files shown w/o requiring a restart
-    m_projectScriptingPlugin = new ProjectScriptingPlugin(this, m_multiEditorAdaptor);
-
-    //guiFactory()->addClient(m_projectScriptingPlugin);
-    //guiFactory()->removeClient(m_projectScriptingPlugin);
-
-    delete m_projectScriptingPlugin;
-    m_projectScriptingPlugin = new ProjectScriptingPlugin(this, m_multiEditorAdaptor);
-    guiFactory()->addClient(m_projectScriptingPlugin);
-}
-
 int LokalizeMainWindow::lookupInTranslationMemory(DocPosition::Part part, const QString& text)
 {
     TM::TMTab* w = showTM();
@@ -1044,15 +870,15 @@ MultiEditorAdaptor::MultiEditorAdaptor(EditorTab *parent)
     : EditorAdaptor(parent)
 {
     setObjectName(QStringLiteral("MultiEditorAdaptor"));
-    connect(parent, QOverload<QObject*>::of(&EditorTab::destroyed), this, QOverload<QObject*>::of(&MultiEditorAdaptor::handleParentDestroy));
+    connect(parent, qOverload<QObject*>(&EditorTab::destroyed), this, qOverload<QObject*>(&MultiEditorAdaptor::handleParentDestroy));
 }
 
 void MultiEditorAdaptor::setEditorTab(EditorTab* e)
 {
     if (parent())
-        disconnect(parent(), QOverload<QObject*>::of(&EditorTab::destroyed), this, QOverload<QObject*>::of(&MultiEditorAdaptor::handleParentDestroy));
+        disconnect(parent(), qOverload<QObject*>(&EditorTab::destroyed), this, qOverload<QObject*>(&MultiEditorAdaptor::handleParentDestroy));
     if (e)
-        connect(e, QOverload<QObject*>::of(&EditorTab::destroyed), this, QOverload<QObject*>::of(&MultiEditorAdaptor::handleParentDestroy));
+        connect(e, qOverload<QObject*>(&EditorTab::destroyed), this, qOverload<QObject*>(&MultiEditorAdaptor::handleParentDestroy));
     setParent(e);
     setAutoRelaySignals(false);
     setAutoRelaySignals(true);
@@ -1086,7 +912,6 @@ void DelayedFileOpener::doOpen()
     deleteLater();
 }
 
-
+#include "moc_lokalizemainwindow.cpp"
 #include "moc_lokalizesubwindowbase.cpp"
 #include "moc_multieditoradaptor.cpp"
-
