@@ -1,24 +1,12 @@
 /*
     Gettext translation file analyzer
 
-    Copyright (C) 2007 Montel Laurent <montel@kde.org>
-    Copyright (C) 2009 Jos van den Oever <jos@vandenoever.info>
-    Copyright (C) 2014 Nick Shaforostoff <shaforostoff@gmail.com>
-                2018-2019 by Simon Depiets <sdepiets@gmail.com>
+    SPDX-FileCopyrightText: 2007 Montel Laurent <montel@kde.org>
+    SPDX-FileCopyrightText: 2009 Jos van den Oever <jos@vandenoever.info>
+    SPDX-FileCopyrightText: 2014 Nick Shaforostoff <shaforostoff@gmail.com>
+    SPDX-FileCopyrightText: 2018-2019 Simon Depiets <sdepiets@gmail.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+    SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
 #include "poextractor.h"
@@ -27,16 +15,6 @@
 
 #include <QFile>
 
-POExtractor::POExtractor()
-    : state(WHITESPACE)
-    , messages(0)
-    , untranslated(0)
-    , fuzzy(0)
-    , isFuzzy(false)
-    , isTranslated(false)
-{
-}
-
 void POExtractor::endMessage()
 {
     messages++;
@@ -126,7 +104,7 @@ void POExtractor::handleLine(const char* data, uint32_t length)
 
 FileMetaData POExtractor::extract(const QString& filePath)
 {
-    std::ifstream fstream(QFile::encodeName(filePath));
+    std::ifstream fstream(QFile::encodeName(filePath).toStdString());
     if (!fstream.is_open()) {
         return {};
     }
@@ -153,9 +131,9 @@ FileMetaData POExtractor::extract(const QString& filePath)
             // handle special values in the first messsage
             // assumption is that value takes up only one line
             if (strncmp("\"POT-Creation-Date: ", line.c_str(), 20) == 0) {
-                m.sourceDate = QByteArray(line.c_str() + 20, line.size() - 21 - 2);
+                m.sourceDate = QString::fromLatin1(QByteArray(line.c_str() + 20, line.size() - 21 - 2));
             } else if (strncmp("\"PO-Revision-Date: ", line.c_str(), 19) == 0) {
-                m.translationDate = QByteArray(line.c_str() + 19, line.size() - 20 - 2);
+                m.translationDate = QString::fromLatin1(QByteArray(line.c_str() + 19, line.size() - 20 - 2));
             } else if (strncmp("\"Last-Translator: ", line.c_str(), 18) == 0) {
                 m.lastTranslator = QString::fromUtf8(QByteArray::fromRawData(line.c_str() + 18, line.size() - 19 - 2));
             }
