@@ -1,26 +1,11 @@
-/* ****************************************************************************
+/*
   This file is part of Lokalize
 
-  Copyright (C) 2009-2014 by Nick Shaforostoff <shafff@ukr.net>
-                2018-2019 by Simon Depiets <sdepiets@gmail.com>
+  SPDX-FileCopyrightText: 2009-2014 Nick Shaforostoff <shafff@ukr.net>
+  SPDX-FileCopyrightText: 2018-2019 Simon Depiets <sdepiets@gmail.com>
 
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License as
-  published by the Free Software Foundation; either version 2 of
-  the License or (at your option) version 3 or any later version
-  accepted by the membership of KDE e.V. (or its successor approved
-  by the membership of KDE e.V.), which shall act as a proxy
-  defined in Section 14 of version 3 of the license.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program.  If not, see <http://www.gnu.org/licenses/>.
-
-**************************************************************************** */
+  SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+*/
 
 #include "noteeditor.h"
 
@@ -62,7 +47,6 @@ NoteEditor::NoteEditor(QWidget* parent)
     , m_fromLabel(new QLabel(i18nc("@info:label", "From:"), this))
     , m_authors(new QStringListModel(this))
     , m_edit(new TextEdit(this))
-    , m_idx(-1)
 {
     setToolTip(i18nc("@info:tooltip", "Save empty note to remove it"));
     m_from->setToolTip(i18nc("@info:tooltip", "Author of this note"));
@@ -140,8 +124,8 @@ int displayNotes(QTextBrowser* browser, const QVector< Note >& notes, int active
             if (i == active)
                 realOffset = t.position();
             QString content = escapeWithLinks(note.content);
-            if (!multiple && content.contains('\n')) content += '\n';
-            content.replace('\n', BR);
+            if (!multiple && content.contains(QLatin1Char('\n'))) content += QLatin1Char('\n');
+            content.replace(QLatin1Char('\n'), BR);
             content += QString(QStringLiteral(" (<a href=\"note:/%1\">")).arg(i) + i18nc("link to edit note", "edit...") + QStringLiteral("</a>)<br />");
             t.insertHtml(content);
             i++;
@@ -154,3 +138,4 @@ int displayNotes(QTextBrowser* browser, const QVector< Note >& notes, int active
     return realOffset;
 }
 
+#include "moc_noteeditor.cpp"
