@@ -22,9 +22,9 @@ class SettingsController: public QObject
 
 public:
     SettingsController();
-    ~SettingsController();
+    ~SettingsController() = default;
 
-    bool dirty;
+    bool dirty{false};
 
     void setMainWindowPtr(QWidget* w)
     {
@@ -51,9 +51,9 @@ Q_SIGNALS:
     void generalSettingsChanged();
 
 private:
-    KEditListWidget* m_scriptsRelPrefWidget; //HACK to get relative filenames in the project file
-    KEditListWidget* m_scriptsPrefWidget;
-    QWidget* m_mainWindowPtr;
+    KEditListWidget* m_scriptsRelPrefWidget{nullptr}; //HACK to get relative filenames in the project file
+    KEditListWidget* m_scriptsPrefWidget{nullptr};
+    QWidget* m_mainWindowPtr{nullptr};
 
 private:
     static SettingsController* _instance;
