@@ -57,8 +57,8 @@ private:
 
 //     bool fromDocbook;
     QTextCharFormat tagFormat;
-    KStatefulBrush tagBrush;
-    bool m_approved;
+    KStatefulBrush tagBrush{KColorScheme::View, KColorScheme::VisitedText};
+    bool m_approved{true};
     QString m_sourceString;
 };
 
