@@ -51,7 +51,6 @@ DBFilesModel* DBFilesModel::instance()
 
 DBFilesModel::DBFilesModel()
     : QSortFilterProxyModel()
-    , projectDB(nullptr)
     , m_fileSystemModel(new QFileSystemModel(this))
     , m_tmRootPath(QStandardPaths::writableLocation(QStandardPaths::DataLocation))
 {
@@ -117,8 +116,8 @@ void DBFilesModel::openDB(const QString& name, DbType type, bool forceCurrentPro
     m_openingDb.append(name);
     m_openingDbLock.unlock();
     if (type == TM::Undefined)
-        type = QFileInfo(
-                   QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1Char('/') + name + QStringLiteral(REMOTETM_DATABASE_EXTENSION)).exists() ? TM::Remote : TM::Local;
+        type = QFileInfo::exists(
+                   QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1Char('/') + name + QStringLiteral(REMOTETM_DATABASE_EXTENSION)) ? TM::Remote : TM::Local;
     OpenDBJob* openDBJob = new OpenDBJob(name, type);
     if (forceCurrentProjectConfig) {
         openDBJob->m_setParams = true;
@@ -187,7 +186,7 @@ void DBFilesModel::removeTM(QModelIndex index)
 void DBFilesModel::closeJobDone(CloseDBJob* j)
 {
     j->deleteLater();
-    QString filename = m_fileSystemModel->rootPath() + '/' + j->dbName() + tmFileExtension;
+    QString filename = m_fileSystemModel->rootPath() + QLatin1Char('/') + j->dbName() + tmFileExtension;
     qCWarning(LOKALIZE_LOG) << "removing file " << filename;
     QFile::remove(filename);
 }
@@ -232,3 +231,4 @@ QVariant DBFilesModel::data(const QModelIndex& index, int role) const
     return res;
 }
 
+#include "moc_dbfilesmodel.cpp"
