@@ -1,26 +1,11 @@
-/* ****************************************************************************
+/*
   This file is part of Lokalize
 
-  Copyright (C) 2011 by Nick Shaforostoff <shafff@ukr.net>
-                2018-2019 by Simon Depiets <sdepiets@gmail.com>
+  SPDX-FileCopyrightText: 2011 Nick Shaforostoff <shafff@ukr.net>
+  SPDX-FileCopyrightText: 2018-2019 Simon Depiets <sdepiets@gmail.com>
 
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License as
-  published by the Free Software Foundation; either version 2 of
-  the License or (at your option) version 3 or any later version
-  accepted by the membership of KDE e.V. (or its successor approved
-  by the membership of KDE e.V.), which shall act as a proxy
-  defined in Section 14 of version 3 of the license.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program.  If not, see <http://www.gnu.org/licenses/>.
-
-**************************************************************************** */
+  SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+*/
 
 
 #include "qaview.h"
@@ -105,7 +90,7 @@ void QaView::removeRule()
 int findMatchingRule(const QVector<Rule>& rules, const QString& source, const QString& target,
                      QVector<StartLen>& positions)
 {
-    for (QVector<Rule>::const_iterator it = rules.constBegin(); it != rules.constEnd(); it++) {
+    for (QVector<Rule>::const_iterator it = rules.constBegin(); it != rules.constEnd(); ++it) {
         if (it->sources.first().indexIn(source) != -1) {
             if (it->falseFriends.first().indexIn(target) != -1) {
                 if (positions.size()) {
@@ -120,3 +105,5 @@ int findMatchingRule(const QVector<Rule>& rules, const QString& source, const QS
     }
     return -1;
 }
+
+#include "moc_qaview.cpp"
