@@ -40,10 +40,9 @@ RecursiveScanJob::RecursiveScanJob(const QString& dbName, QObject* parent)
 
 bool RecursiveScanJob::doKill()
 {
-#if QT_VERSION >= 0x050500
-    for (ScanJob* job : qAsConst(m_jobs))
-        TM::threadPool()->tryTake(job);
-#endif
+    for (auto job : qAsConst(m_jobs)) {
+        [[maybe_unused]] const bool result = TM::threadPool()->tryTake(job);
+    }
     return true;
 }
 
@@ -125,7 +124,7 @@ static QVector<ScanJob*> TM::doScanRecursive(const QDir& dir, const QString& dbN
     QStringList filters = Catalog::supportedExtensions();
     i = filters.size();
     while (--i >= 0)
-        filters[i].prepend('*');
+        filters[i].prepend(QLatin1Char('*'));
     QStringList files(dir.entryList(filters, QDir::Files | QDir::NoDotAndDotDot | QDir::Readable));
     i = files.size();
 
@@ -166,4 +165,4 @@ QString shorterFilePath(const QString path)
     return path;
 }
 
-
+#include "moc_tmscanapi.cpp"
