@@ -59,8 +59,6 @@ using namespace TM;
 //BEGIN TMDBModel
 TMDBModel::TMDBModel(QObject* parent)
     : QSqlQueryModel(parent)
-    , m_queryType(WordOrder)
-    , m_totalResultCount(0)
 {
     setHeaderData(TMDBModel::Source,            Qt::Horizontal, i18nc("@title:column Original text", "Source"));
     setHeaderData(TMDBModel::Target,            Qt::Horizontal, i18nc("@title:column Text in target language", "Target"));
@@ -73,10 +71,15 @@ void TMDBModel::setDB(const QString& str)
 {
     m_dbName = str;
 
-    QString sourceLangCode = DBFilesModel::instance()->m_configurations.value(str).sourceLangCode;
-    QString targetLangCode = DBFilesModel::instance()->m_configurations.value(str).targetLangCode;
-    if (sourceLangCode.length()) setHeaderData(TMDBModel::Source, Qt::Horizontal, QString(i18nc("@title:column Original text", "Source") + QStringLiteral(": ") + sourceLangCode));
-    if (targetLangCode.length()) setHeaderData(TMDBModel::Target, Qt::Horizontal, QString(i18nc("@title:column Text in target language", "Target") + QStringLiteral(": ") + targetLangCode));
+    const QString sourceLangCode = DBFilesModel::instance()->m_configurations.value(str).sourceLangCode;
+    if (!sourceLangCode.isEmpty()) {
+        setHeaderData(TMDBModel::Source, Qt::Horizontal, i18nc("@title:column Original text", "Source: %1", sourceLangCode));
+    }
+
+    const QString targetLangCode = DBFilesModel::instance()->m_configurations.value(str).targetLangCode;
+    if (!targetLangCode.isEmpty()) {
+        setHeaderData(TMDBModel::Target, Qt::Horizontal, i18nc("@title:column Text in target language", "Target: %1", targetLangCode));
+    }
 }
 
 void TMDBModel::setQueryType(int type)
@@ -89,18 +92,18 @@ void TMDBModel::setFilter(const QString& source, const QString& target,
                           const QString& filemask
                          )
 {
-    QString escapedSource(source); escapedSource.replace('\'', QStringLiteral("''"));
-    QString escapedTarget(target); escapedTarget.replace('\'', QStringLiteral("''"));
+    QString escapedSource(source); escapedSource.replace(QLatin1Char('\''), QStringLiteral("''"));
+    QString escapedTarget(target); escapedTarget.replace(QLatin1Char('\''), QStringLiteral("''"));
     QString invertSourceStr; if (invertSource) invertSourceStr = QStringLiteral("NOT ");
     QString invertTargetStr; if (invertTarget) invertTargetStr = QStringLiteral("NOT ");
-    QString escapedFilemask(filemask); escapedFilemask.replace('\'', QStringLiteral("''"));
+    QString escapedFilemask(filemask); escapedFilemask.replace(QLatin1Char('\''), QStringLiteral("''"));
     QString sourceQuery;
     QString targetQuery;
     QString fileQuery;
 
     if (m_queryType == SubStr) {
-        escapedSource.replace('%', QStringLiteral("\b%")); escapedSource.replace('_', QStringLiteral("\b_"));
-        escapedTarget.replace('%', QStringLiteral("\b%")); escapedTarget.replace('_', QStringLiteral("\b_"));
+        escapedSource.replace(QLatin1Char('%'), QStringLiteral("\b%")); escapedSource.replace(QLatin1Char('_'), QStringLiteral("\b_"));
+        escapedTarget.replace(QLatin1Char('%'), QStringLiteral("\b%")); escapedTarget.replace(QLatin1Char('_'), QStringLiteral("\b_"));
         if (!escapedSource.isEmpty())
             sourceQuery = QStringLiteral("AND source_strings.source ") + invertSourceStr + QStringLiteral("LIKE '%") + escapedSource + QStringLiteral("%' ESCAPE '\b' ");
         if (!escapedTarget.isEmpty())
@@ -211,7 +214,7 @@ QVariant TMDBModel::data(const QModelIndex& item, int role) const
 
     if (item.column() == TMDBModel::Context) { //context
         QString r = result.toString();
-        int pos = r.indexOf(TM_DELIMITER);
+        int pos = r.indexOf(QLatin1Char(TM_DELIMITER));
         if (pos != -1)
             result = r.remove(pos, r.size());
     } else if (item.column() < TMDBModel::Context && !record(item.row()).isNull(TMDBModel::_SourceAccel + item.column())) { //source, target
@@ -246,7 +249,7 @@ QVariant TMDBModel::data(const QModelIndex& item, int role) const
 class TMResultsSortFilterProxyModel: public QSortFilterProxyModel
 {
 public:
-    TMResultsSortFilterProxyModel(QObject *parent)
+    explicit TMResultsSortFilterProxyModel(QObject *parent)
         : QSortFilterProxyModel(parent)
     {}
     void setRules(const QVector<Rule>& rules);
@@ -266,8 +269,8 @@ private:
 bool TMResultsSortFilterProxyModel::lessThan(const QModelIndex& left, const QModelIndex& right) const
 {
     if (left.column() == TMDBModel::TransationStatus) {
-        int l = left.data(TMDBModel::TransStateRole).toInt();
-        int r = right.data(TMDBModel::TransStateRole).toInt();
+        const int l = left.data(TMDBModel::TransStateRole).toInt();
+        const int r = right.data(TMDBModel::TransStateRole).toInt();
         return l < r;
     }
     return QSortFilterProxyModel::lessThan(left, right);
@@ -376,8 +379,6 @@ QVariant QueryStylesModel::data(const QModelIndex& item, int role) const
 TMTab::TMTab(QWidget *parent)
     : LokalizeSubwindowBase2(parent)
     , m_proxyModel(new TMResultsSortFilterProxyModel(this))
-    , m_partToAlsoTryLater(DocPosition::UndefPart)
-    , m_dbusId(-1)
 {
     //setCaption(i18nc("@title:window","Translation Memory"),false);
     setWindowTitle(i18nc("@title:window", "Translation Memory"));
@@ -396,7 +397,7 @@ TMTab::TMTab(QWidget *parent)
     connect(ui_queryOptions->doUpdateTM, &QPushButton::clicked, this, &TMTab::updateTM);
 
     QShortcut* sh = new QShortcut(Qt::CTRL + Qt::Key_L, this);
-    connect(sh, &QShortcut::activated, ui_queryOptions->querySource, QOverload<>::of(&QLineEdit::setFocus));
+    connect(sh, &QShortcut::activated, ui_queryOptions->querySource, qOverload<>(&QLineEdit::setFocus));
     setFocusProxy(ui_queryOptions->querySource);
 
     QTreeView* view = ui_queryOptions->treeView;
@@ -449,7 +450,6 @@ TMTab::TMTab(QWidget *parent)
     view->setItemDelegate(new FastSizeHintItemDelegate(this, singleLineColumns, richTextColumns));
     connect(m_model, &TMDBModel::resultsFetched, (FastSizeHintItemDelegate*)view->itemDelegate(), &FastSizeHintItemDelegate::reset);
     connect(m_model, &TMDBModel::modelReset, (FastSizeHintItemDelegate*)view->itemDelegate(), &FastSizeHintItemDelegate::reset);
-    //connect(m_model,SIGNAL(rowsMoved(QModelIndex,int,int,QModelIndex,int)),view->itemDelegate(),SLOT(reset()));
     connect(m_proxyModel, &TMResultsSortFilterProxyModel::layoutChanged, (FastSizeHintItemDelegate*)view->itemDelegate(), &FastSizeHintItemDelegate::reset);
     connect(m_proxyModel, &TMResultsSortFilterProxyModel::layoutChanged, this, &TMTab::displayTotalResultCount);
 
@@ -458,15 +458,19 @@ TMTab::TMTab(QWidget *parent)
     connect(m_model, &TMDBModel::finalResultCountFetched, this, &TMTab::displayTotalResultCount);
 
     ui_queryOptions->queryStyle->setModel(new QueryStylesModel(this));
-    connect(ui_queryOptions->queryStyle, QOverload<int>::of(&KComboBox::currentIndexChanged), m_model, &TMDBModel::setQueryType);
+    connect(ui_queryOptions->queryStyle, qOverload<int>(&KComboBox::currentIndexChanged), m_model, &TMDBModel::setQueryType);
 
     ui_queryOptions->dbName->setModel(DBFilesModel::instance());
     ui_queryOptions->dbName->setRootModelIndex(DBFilesModel::instance()->rootIndex());
-    int pos = ui_queryOptions->dbName->findData(Project::instance()->projectID(), DBFilesModel::NameRole);
-    if (pos >= 0)
+    const int pos = ui_queryOptions->dbName->findData(Project::instance()->projectID(), DBFilesModel::NameRole);
+    if (pos >= 0) {
         ui_queryOptions->dbName->setCurrentIndex(pos);
-    connect(ui_queryOptions->dbName, QOverload<const QString &>::of(&QComboBox::currentIndexChanged), m_model, &TMDBModel::setDB);
-    //connect(ui_queryOptions->dbName, SIGNAL(activated(QString)), this, SLOT(performQuery()));
+    }
+    const auto combo = ui_queryOptions->dbName;
+    connect(combo, qOverload<int>(&QComboBox::currentIndexChanged),
+            m_model, [this, combo](const int index) {
+        m_model->setDB(combo->itemText(index));
+    });
 
 //BEGIN resizeColumnToContents
     static const int maxInitialWidths[4] = {QGuiApplication::primaryScreen()->availableGeometry().width() / 3, QGuiApplication::primaryScreen()->availableGeometry().width() / 3, 50, 200};
@@ -497,8 +501,8 @@ TMTab::TMTab(QWidget *parent)
     addDockWidget(Qt::RightDockWidgetArea, m_qaView);
     tm->addAction(QStringLiteral("showqa_action"), m_qaView->toggleViewAction());
 
-    connect(m_qaView, &QaView::rulesChanged, this, QOverload<>::of(&TMTab::setQAMode));
-    connect(m_qaView->toggleViewAction(), &QAction::toggled, this, QOverload<bool>::of(&TMTab::setQAMode));
+    connect(m_qaView, &QaView::rulesChanged, this, qOverload<>(&TMTab::setQAMode));
+    connect(m_qaView->toggleViewAction(), &QAction::toggled, this, qOverload<bool>(&TMTab::setQAMode));
 
 
     KConfig config;
@@ -572,8 +576,8 @@ void TMTab::handleResults()
                                    DocPosition::Comment;  //leave a note that we should also try w/o package if the current one doesn't succeed
             return performQuery();
         }
-        if (!filemask.isEmpty() && !filemask.contains('*')) {
-            ui_queryOptions->filemask->setText('*' + filemask + '*');
+        if (!filemask.isEmpty() && !filemask.contains(QLatin1Char('*'))) {
+            ui_queryOptions->filemask->setText(QLatin1Char('*') + filemask + QLatin1Char('*'));
             return performQuery();
         }
     }
@@ -771,7 +775,7 @@ bool TMTab::findGuiTextPackage(QString text, QString package)
     source_target_query[tryNowPart == DocPosition::Source]->setText(text);
     ui_queryOptions->invertSource->setChecked(false);
     ui_queryOptions->invertTarget->setChecked(false);
-    if (!package.isEmpty()) package = '*' + package + '*';
+    if (!package.isEmpty()) package = QLatin1Char('*') + package + QLatin1Char('*');
     ui_queryOptions->filemask->setText(package);
     ui_queryOptions->queryStyle->setCurrentIndex(TMDBModel::Glob);
     performQuery();
@@ -779,3 +783,5 @@ bool TMTab::findGuiTextPackage(QString text, QString package)
     return true;
 }
 //END DBus interface
+
+#include "moc_tmtab.cpp"
