@@ -22,9 +22,10 @@
 #include "diff.h"
 #include "xlifftextedit.h"
 
+#include <kcoreaddons_version.h>
 #include <klocalizedstring.h>
 #include <kmessagebox.h>
-#include <kpassivepopup.h>
+#include <knotification.h>
 
 #include <QTime>
 #include <QDragEnterEvent>
@@ -45,7 +46,7 @@ using namespace TM;
 
 
 struct DiffInfo {
-    DiffInfo(int reserveSize);
+    explicit DiffInfo(int reserveSize);
 
     QString diffClean;
     QString old;
@@ -78,7 +79,7 @@ static DiffInfo getDiffInfo(const QString& diff)
 {
     DiffInfo d(diff.size());
 
-    QChar sep('{');
+    QChar sep(QLatin1Char('{'));
     char state = '0';
     //walk through diff string char-by-char
     //calculate old and others
@@ -113,7 +114,7 @@ void TextBrowser::mouseDoubleClickEvent(QMouseEvent* event)
     QTextBrowser::mouseDoubleClickEvent(event);
 
     QString sel = textCursor().selectedText();
-    if (!(sel.isEmpty() || sel.contains(' ')))
+    if (!(sel.isEmpty() || sel.contains(QLatin1Char(' '))))
         Q_EMIT textInsertRequested(sel);
 }
 
@@ -122,14 +123,10 @@ TMView::TMView(QWidget* parent, Catalog* catalog, const QVector<QAction*>& actio
     : QDockWidget(i18nc("@title:window", "Translation Memory"), parent)
     , m_browser(new TextBrowser(this))
     , m_catalog(catalog)
-    , m_currentSelectJob(nullptr)
     , m_actions_insert(actions_insert)
     , m_actions_remove(actions_remove)
     , m_normTitle(i18nc("@title:window", "Translation Memory"))
     , m_hasInfoTitle(m_normTitle + QStringLiteral(" [*]"))
-    , m_hasInfo(false)
-    , m_isBatching(false)
-    , m_markAsFuzzy(false)
 {
     setObjectName(QStringLiteral("TMView"));
     setWidget(m_browser);
@@ -138,16 +135,14 @@ TMView::TMView(QWidget* parent, Catalog* catalog, const QVector<QAction*>& actio
     m_browser->viewport()->setBackgroundRole(QPalette::Window);
 
     QTimer::singleShot(0, this, &TMView::initLater);
-    connect(m_catalog, QOverload<const QString &>::of(&Catalog::signalFileLoaded), this, &TMView::slotFileLoaded);
+    connect(m_catalog, qOverload<const QString &>(&Catalog::signalFileLoaded), this, &TMView::slotFileLoaded);
 }
 
 TMView::~TMView()
 {
-#if QT_VERSION >= 0x050500
-    int i = m_jobs.size();
-    while (--i >= 0)
-        TM::threadPool()->tryTake(m_jobs.at(i));
-#endif
+    for (auto job : qAsConst(m_jobs)) {
+        [[maybe_unused]] const bool result = TM::threadPool()->tryTake(job);
+    }
 }
 
 void TMView::initLater()
@@ -203,11 +198,9 @@ void TMView::slotFileLoaded(const QString& filePath)
         return;
 
     m_cache.clear();
-#if QT_VERSION >= 0x050500
-    int i = m_jobs.size();
-    while (--i >= 0)
-        TM::threadPool()->tryTake(m_jobs.at(i));
-#endif
+    for (auto job : qAsConst(m_jobs)) {
+        [[maybe_unused]] const bool result = TM::threadPool()->tryTake(job);
+    }
     m_jobs.clear();
 
     DocPosition pos;
@@ -288,14 +281,14 @@ void TMView::slotBatchSelectDone()
         m_catalog->endMacro();
     else {
         // xgettext: no-c-format
-        msg += ' ';
+        msg += QLatin1Char(' ');
         msg += i18nc("@info", "No suggestions with exact matches were found.");
     }
 
-    KPassivePopup::message(KPassivePopup::Balloon,
-                           i18nc("@title", "Batch translation complete"),
-                           msg,
-                           this);
+    KNotification *notification = new KNotification(QStringLiteral("BatchTranslationCompleted"));
+    notification->setWidget(this);
+    notification->setText(msg);
+    notification->sendEvent();
 }
 
 void TMView::slotBatchTranslate()
@@ -306,11 +299,11 @@ void TMView::slotBatchTranslate()
         slotFileLoaded(m_catalog->url());
     else if (m_jobs.isEmpty())
         return slotBatchSelectDone();
-    KPassivePopup::message(KPassivePopup::Balloon,
-                           i18nc("@title", "Batch translation"),
-                           i18nc("@info", "Batch translation has been scheduled."),
-                           this);
 
+    KNotification *notification = new KNotification(QStringLiteral("BatchTranslationScheduled"));
+    notification->setWidget(this);
+    notification->setText(i18nc("@info", "Batch translation has been scheduled."));
+    notification->sendEvent();
 }
 
 void TMView::slotBatchTranslateFuzzy()
@@ -321,11 +314,11 @@ void TMView::slotBatchTranslateFuzzy()
         slotFileLoaded(m_catalog->url());
     else if (m_jobs.isEmpty())
         slotBatchSelectDone();
-    KPassivePopup::message(KPassivePopup::Balloon,
-                           i18nc("@title", "Batch translation"),
-                           i18nc("@info", "Batch translation has been scheduled."),
-                           this);
 
+    KNotification *notification = new KNotification(QStringLiteral("BatchTranslationScheduled"));
+    notification->setWidget(this);
+    notification->setText(i18nc("@info", "Batch translation has been scheduled."));
+    notification->sendEvent();
 }
 
 void TMView::slotNewEntryDisplayed()
@@ -338,11 +331,9 @@ void TMView::slotNewEntryDisplayed(const DocPosition& pos)
     if (m_catalog->numberOfEntries() <= pos.entry)
         return;//because of Qt::QueuedConnection
 
-#if QT_VERSION >= 0x050500
-    int i = m_jobs.size();
-    while (--i >= 0)
-        TM::threadPool()->tryTake(m_currentSelectJob);
-#endif
+    for (auto job : qAsConst(m_jobs)) {
+        [[maybe_unused]] const bool result = TM::threadPool()->tryTake(job);
+    }
 
     //update DB
     //m_catalog->flushUpdateDBBuffer();
@@ -558,8 +549,19 @@ bool TMView::event(QEvent *event)
 
 void TMView::removeEntry(const TMEntry& e)
 {
-    if (KMessageBox::Yes == KMessageBox::questionYesNo(this, i18n("<html>Do you really want to remove this entry:<br/><i>%1</i><br/>from translation memory %2?</html>",  e.target.string.toHtmlEscaped(), e.dbName),
-            i18nc("@title:window", "Translation Memory Entry Removal"))) {
+#if KCOREADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+    if (KMessageBox::PrimaryAction == KMessageBox::questionTwoActions(
+                this,
+                i18n("<html>Do you really want to remove this entry:<br/><i>%1</i><br/>from translation memory %2?</html>",  e.target.string.toHtmlEscaped(), e.dbName),
+                i18nc("@title:window", "Translation Memory Entry Removal"),
+                KStandardGuiItem::remove(),
+                KStandardGuiItem::cancel())) {
+#else
+    if (KMessageBox::Yes == KMessageBox::questionYesNo(
+                this,
+                i18n("<html>Do you really want to remove this entry:<br/><i>%1</i><br/>from translation memory %2?</html>",  e.target.string.toHtmlEscaped(), e.dbName),
+                i18nc("@title:window", "Translation Memory Entry Removal"))) {
+#endif
         RemoveJob* job = new RemoveJob(e);
         connect(job, SIGNAL(done()), this, SLOT(slotNewEntryDisplayed()));
         TM::threadPool()->start(job, REMOVE);
@@ -588,17 +590,19 @@ void TMView::contextMenu(const QPoint& pos)
     if (block >= m_entries.size())
         return;
 
-    const TMEntry& e = m_entries.at(block);
+    const auto * e = &m_entries.at(block);
+
     enum {Remove, RemoveFile, Open};
     QMenu popup;
     popup.addAction(i18nc("@action:inmenu", "Remove this entry"))->setData(Remove);
-    if (e.file != m_catalog->url() && QFile::exists(e.file))
+    if (e->file != m_catalog->url() && QFile::exists(e->file))
         popup.addAction(i18nc("@action:inmenu", "Open file containing this entry"))->setData(Open);
     else {
         if (Settings::deleteFromTMOnMissing()) {
             //Automatic deletion
-            deleteFile(e, true);
-        } else if (!QFile::exists(e.file)) {
+            deleteFile(*e, true);
+            e = &m_entries.at(block); // e points to an invalid addres after TMView::deleteFile
+        } else if (!QFile::exists(e->file)) {
             //Still offer manual deletion if this is not the current file
             popup.addAction(i18nc("@action:inmenu", "Remove this missing file from TM"))->setData(RemoveFile);
         }
@@ -607,13 +611,23 @@ void TMView::contextMenu(const QPoint& pos)
     if (!r)
         return;
     if (r->data().toInt() == Remove) {
-        removeEntry(e);
+        removeEntry(*e);
     } else if (r->data().toInt() == Open) {
-        Q_EMIT fileOpenRequested(e.file, e.source.string, e.ctxt, true);
+        Q_EMIT fileOpenRequested(e->file, e->source.string, e->ctxt, true);
+#if KCOREADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+    } else if ((r->data().toInt() == RemoveFile)
+               && KMessageBox::PrimaryAction == KMessageBox::questionTwoActions(
+                   this,
+                   i18n("<html>Do you really want to remove this missing file:<br/><i>%1</i><br/>from translation memory %2?</html>",  e->file, e->dbName),
+                   i18nc("@title:window", "Translation Memory Missing File Removal"),
+                   KStandardGuiItem::remove(),
+                   KStandardGuiItem::cancel())) {
+#else
     } else if ((r->data().toInt() == RemoveFile) &&
-               KMessageBox::Yes == KMessageBox::questionYesNo(this, i18n("<html>Do you really want to remove this missing file:<br/><i>%1</i><br/>from translation memory %2?</html>",  e.file, e.dbName),
+               KMessageBox::Yes == KMessageBox::questionYesNo(this, i18n("<html>Do you really want to remove this missing file:<br/><i>%1</i><br/>from translation memory %2?</html>",  e->file, e->dbName),
                        i18nc("@title:window", "Translation Memory Missing File Removal"))) {
-        deleteFile(e, false);
+#endif
+        deleteFile(*e, false);
     }
 }
 
@@ -685,10 +699,10 @@ CatalogString TM::targetAdapted(const TMEntry& entry, const CatalogString& ref)
     //first things first
     int pos = 0;
     while ((pos = rxDel.indexIn(diff, pos)) != -1)
-        diff.replace(pos, rxDel.matchedLength(), "\tKBABELDEL\t" + rxDel.cap(1) + "\t/KBABELDEL\t");
+        diff.replace(pos, rxDel.matchedLength(), QStringLiteral("\tKBABELDEL\t") + rxDel.cap(1) + QStringLiteral("\t/KBABELDEL\t"));
     pos = 0;
     while ((pos = rxAdd.indexIn(diff, pos)) != -1)
-        diff.replace(pos, rxAdd.matchedLength(), "\tKBABELADD\t" + rxAdd.cap(1) + "\t/KBABELADD\t");
+        diff.replace(pos, rxAdd.matchedLength(), QStringLiteral("\tKBABELADD\t") + rxAdd.cap(1) + QStringLiteral("\t/KBABELADD\t"));
 
     diff.replace(QStringLiteral("&lt;"), QStringLiteral("<"));
     diff.replace(QStringLiteral("&gt;"), QStringLiteral(">"));
@@ -936,7 +950,7 @@ CatalogString TM::targetAdapted(const TMEntry& entry, const CatalogString& ref)
                 if (diffMPart.at(j) != '-')
                     newMarkup.append(d.diffClean.at(startPos + j));
             }
-            if (newMarkup.endsWith(' ')) newMarkup.chop(1);
+            if (newMarkup.endsWith(QLatin1Char(' '))) newMarkup.chop(1);
             //qCWarning(LOKALIZE_LOG)<<"d.old"<<cap<<"new"<<newMarkup;
 
 
@@ -1010,3 +1024,4 @@ void TMView::slotUseSuggestion(int i)
     Q_EMIT refreshRequested();
 }
 
+#include "moc_tmview.cpp"
